@@ -73,7 +73,7 @@ GtkWidget *creation_onglet_accueil ( void )
     /* cration du logo */
 
     if ( !chemin_logo || !strlen ( chemin_logo ))
-	chemin_logo = LOGO_PATH;
+	chemin_logo = g_strdup ( LOGO_PATH );
 
     if ( etat.utilise_logo )
     {
@@ -392,7 +392,6 @@ gboolean saisie_echeance_accueil ( GtkWidget *event_box,
 /* ************************************************************************* */
 
 
-
 /* ************************************************************************* */
 /* Fonction update_liste_comptes_accueil                                     */
 /* affiche la liste des comptes et leur solde courant dans la frame qui leur */
@@ -413,7 +412,6 @@ void update_liste_comptes_accueil ( void )
     gint i;
     gint nb_comptes_bancaires=0, nb_comptes_passif=0, nb_comptes_actif=0;
 
-
     if ( !nb_comptes )
 	return;
 
@@ -468,7 +466,6 @@ void update_liste_comptes_accueil ( void )
     vbox = gtk_vbox_new ( FALSE, 6 );
     gtk_container_add ( GTK_CONTAINER ( frame_etat_comptes_accueil ), vbox );
 
-
     /* Prparation de la sparation de l'affichage des comptes en fonction
        de leur type */
 
@@ -518,7 +515,6 @@ void update_liste_comptes_accueil ( void )
 	if ( !devise_is_used )
 	    continue;
 
-
 	/* Cration du tableau dans lequel seront stocks les comptes avec leur     */
 	/* solde.                                                                   */
 	paddingbox = new_paddingbox_with_title ( vbox, FALSE,
@@ -561,9 +557,9 @@ void update_liste_comptes_accueil ( void )
 
 		/* Est-il rellement ncessaire de crer des labels vides pour */
 		/* remplir des colonnes vides d'un tableau ?                   */
-		pLabel = gtk_label_new ( "" );
-		gtk_table_attach_defaults ( GTK_TABLE ( pTable ), pLabel, 0, 1, i, i+1 );
-		gtk_widget_show ( pLabel );
+/* 		pLabel = gtk_label_new ( "" ); */
+/* 		gtk_table_attach_defaults ( GTK_TABLE ( pTable ), pLabel, 0, 1, i, i+1 ); */
+/* 		gtk_widget_show ( pLabel ); */
 
 		/* Deuxime colonne : elle contient le nom du compte */
 		pLabel = gtk_label_new ( g_strconcat ( (gchar *) NOM_DU_COMPTE, " : ", NULL ));
@@ -687,9 +683,9 @@ void update_liste_comptes_accueil ( void )
 		gtk_widget_show ( pLabel );
 
 		/* Cinquime colonne : vide */
-		pLabel = gtk_label_new ("");
-		gtk_table_attach_defaults ( GTK_TABLE ( pTable ), pLabel, 4, 5, i, i+1 );
-		gtk_widget_show ( pLabel );
+/* 		pLabel = gtk_label_new (""); */
+/* 		gtk_table_attach_defaults ( GTK_TABLE ( pTable ), pLabel, 4, 5, i, i+1 ); */
+/* 		gtk_widget_show ( pLabel ); */
 
 		/* Sixime colonne : elle contient le solde courant du compte */
 		pLabel = gtk_label_new ( g_strdup_printf ( "%4.2f", SOLDE_COURANT ));
@@ -749,9 +745,9 @@ void update_liste_comptes_accueil ( void )
 		gtk_widget_show ( pLabel );
 
 		/* Huitime colonne : vide */
-		pLabel = gtk_label_new ("");
-		gtk_table_attach_defaults ( GTK_TABLE ( pTable ), pLabel, 7, 8, i, i+1 );
-		gtk_widget_show ( pLabel );
+/* 		pLabel = gtk_label_new (""); */
+/* 		gtk_table_attach_defaults ( GTK_TABLE ( pTable ), pLabel, 7, 8, i, i+1 ); */
+/* 		gtk_widget_show ( pLabel ); */
 
 		/* ATTENTION : les sommes effectues ici prsupposent que
 		   TOUS les comptes sont dans la MME DEVISE !!!!!        */
