@@ -32,6 +32,7 @@
 #include "search_glist.h"
 #include "traitement_variables.h"
 #include "utils.h"
+#include "utils_file_selection.h"
 
 
 GtkWidget * list_font_name_label, * list_font_size_label;
@@ -51,6 +52,7 @@ extern GtkWidget *separateur_formulaire_echeancier;
 extern GtkWidget *hbox_valider_annuler_echeance;
 extern GtkWidget *liste_echeances;
 
+
 /**
  * Updates transaction form according to state "etat"
  *
@@ -556,11 +558,13 @@ gboolean change_choix_utilise_fonte_liste ( GtkWidget *check_button,
     style_couleur[1] -> font_desc =  fonte_desc;
     style_rouge_couleur[0] -> font_desc = fonte_desc;
     style_rouge_couleur[1] -> font_desc = fonte_desc;
+    style_gris -> font_desc = fonte_desc;
 
     gtk_style_set_font (style_couleur [0], NULL);
     gtk_style_set_font (style_couleur [1], NULL);
     gtk_style_set_font (style_rouge_couleur [0], NULL);
     gtk_style_set_font (style_rouge_couleur [1], NULL);
+    gtk_style_set_font (style_gris, NULL);
 
     /* Find font size */
 
@@ -722,7 +726,7 @@ void update_font_button(GtkWidget * name_label,
 
     font_name = g_strdup ( fontname );
     tmp = font_name + strlen(font_name) - 1;
-    while (isdigit(*tmp) ||
+    while (g_ascii_isdigit(*tmp) ||
 	   (*tmp) == '.')
 	tmp --;
     font_size = tmp+1;
@@ -739,7 +743,7 @@ void update_font_button(GtkWidget * name_label,
 }
 
 
-/* **************************************************************************************************************************** */
+
 /**
  * Reset fonts to their initial value, that is "Sans 10".  Update
  * fonts buttons as well.
@@ -766,10 +770,13 @@ gboolean init_fonts ( GtkWidget * button,
 	style_couleur[1] -> font_desc = pango_font_description_from_string(fonte_liste);
 	style_rouge_couleur[0] -> font_desc = pango_font_description_from_string(fonte_liste);
 	style_rouge_couleur[1] -> font_desc = pango_font_description_from_string(fonte_liste);
+	style_gris -> font_desc = pango_font_description_from_string(fonte_liste);
+
 	gtk_style_set_font (style_couleur [0], NULL);
 	gtk_style_set_font (style_couleur [1], NULL);
 	gtk_style_set_font (style_rouge_couleur [0], NULL);
 	gtk_style_set_font (style_rouge_couleur [1], NULL);
+	gtk_style_set_font (style_gris, NULL);
 
 	/* Find font size */
 	p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
@@ -832,10 +839,12 @@ void choix_fonte ( GtkWidget *bouton,
 	style_couleur[1] -> font_desc = pango_font_description_from_string(fontname);
 	style_rouge_couleur[0] -> font_desc = pango_font_description_from_string(fontname);
 	style_rouge_couleur[1] -> font_desc = pango_font_description_from_string(fontname);
+	style_gris -> font_desc = pango_font_description_from_string(fontname);
 	gtk_style_set_font (style_couleur [0], NULL);
 	gtk_style_set_font (style_couleur [1], NULL);
 	gtk_style_set_font (style_rouge_couleur [0], NULL);
 	gtk_style_set_font (style_rouge_couleur [1], NULL);
+	gtk_style_set_font (style_gris, NULL);
 
 	/* Find font size */
 	p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
@@ -863,12 +872,12 @@ void change_logo_accueil ( GtkWidget *widget, gpointer user_data )
     GdkPixbuf * pixbuf;
     const gchar *selected_filename;
 
-    selected_filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (file_selector));
+    selected_filename = file_selection_get_filename (GTK_FILE_SELECTION (file_selector));
 
     if ( nb_comptes )
     {
 	/* on change le logo */
-	chemin_logo = (gchar *) selected_filename;
+        chemin_logo = g_strdup ( (gchar *) selected_filename );
 
 	if ( !chemin_logo ||
 	     !strlen ( g_strstrip ( chemin_logo )) )
@@ -927,7 +936,7 @@ void change_animation ( GtkWidget *widget,
     GtkWidget *file_selector = (GtkWidget *)user_data;
     GdkPixbufAnimation *pixbuf=NULL;
 
-    etat.fichier_animation_attente = g_strdup (gtk_file_selection_get_filename (GTK_FILE_SELECTION (file_selector)));
+    etat.fichier_animation_attente = file_selection_get_filename (GTK_FILE_SELECTION (file_selector));
 
 
     if ( !etat.fichier_animation_attente
