@@ -38,6 +38,8 @@
 #include "tiers_onglet.h"
 #include "traitement_variables.h"
 #include "utils.h"
+#include "utils_files.h"
+#include "utils_file_selection.h"
 
 
 
@@ -1377,7 +1379,8 @@ void expand_selected_category ()
 	operation = gtk_ctree_node_get_row_data ( GTK_CTREE ( arbre_categ ),
 						  GTK_CTREE_NODE ( ( GTK_CLIST ( arbre_categ ) -> selection ) -> data ) );
 
-	if (!operation || operation == GINT_TO_POINTER(-1))
+	if ( !operation || operation == GINT_TO_POINTER(-1) ||
+	     (gint) operation < nb_comptes ) /* Kludge attack */
 	    return;
 
 	/* si c'est une op de ventilation, on se place sur l'op
@@ -2881,6 +2884,16 @@ void appui_sur_ajout_categorie ( void )
 					    COLON(_("Enter name for new category")) )))
 	return;
 
+    if ( g_slist_find_custom ( liste_struct_categories,
+			       nom_categorie,
+			       (GCompareFunc) recherche_categorie_par_nom ) )
+      {
+	dialogue_warning_hint ( _("Category names must be both unique and not empty.  Please use another name for this category."),
+				g_strdup_printf ( _("Category '%s' already exists."),
+						  nom_categorie ) );
+	return;
+      }
+
     /* on l'ajoute  la liste des ops */
 
     nouvelle_categorie = ajoute_nouvelle_categorie ( nom_categorie );
@@ -2950,6 +2963,16 @@ void appui_sur_ajout_sous_categorie ( void )
     if ( categorie <= 0 )
 	return;
 
+    if ( g_slist_find_custom ( categorie -> liste_sous_categ,
+			       nom_sous_categorie,
+			       (GCompareFunc) recherche_sous_categorie_par_nom ) )
+      {
+	dialogue_warning_hint ( _("Sub-category names must be both unique and not empty.  Please use another name for this sub-category."),
+				g_strdup_printf ( _("Sub-category '%s' already exists."),
+						  nom_sous_categorie ) );
+	return;
+      }
+
     /* on l'ajoute  la liste des ops */
 
     nouvelle_sous_categorie = ajoute_nouvelle_sous_categorie ( nom_sous_categorie,
@@ -3002,17 +3025,16 @@ void exporter_categ ( void )
     gchar *nom_categ;
 
     fenetre_nom = gtk_file_selection_new ( _("Export categories"));
-    gtk_file_selection_set_filename ( GTK_FILE_SELECTION ( fenetre_nom ),
+    file_selection_set_filename ( GTK_FILE_SELECTION ( fenetre_nom ),
 				      dernier_chemin_de_travail );
-    gtk_entry_set_text ( GTK_ENTRY ( GTK_FILE_SELECTION ( fenetre_nom )->selection_entry),
-			 ".cgsb" );
+    file_selection_set_entry (  GTK_FILE_SELECTION ( fenetre_nom ), ".cgsb" );
 
     resultat = gtk_dialog_run ( GTK_DIALOG ( fenetre_nom ));
 
     switch ( resultat )
     {
 	case GTK_RESPONSE_OK :
-	    nom_categ =g_strdup (gtk_file_selection_get_filename ( GTK_FILE_SELECTION ( fenetre_nom )));
+	    nom_categ = file_selection_get_filename ( GTK_FILE_SELECTION ( fenetre_nom ));
 
 	    gtk_widget_destroy ( GTK_WIDGET ( fenetre_nom ));
 
@@ -3021,7 +3043,7 @@ void exporter_categ ( void )
 	    if ( !strlen ( nom_categ ))
 		return;
 
-	    if ( stat ( nom_categ,
+	    if ( utf8_stat ( nom_categ,
 			&test_fichier ) != -1 )
 	    {
 		if ( S_ISREG ( test_fichier.st_mode ) )
@@ -3069,10 +3091,9 @@ void importer_categ ( void )
 
 
     fenetre_nom = gtk_file_selection_new ( _("Import a category list"));
-    gtk_file_selection_set_filename ( GTK_FILE_SELECTION ( fenetre_nom ),
+    file_selection_set_filename ( GTK_FILE_SELECTION ( fenetre_nom ),
 				      dernier_chemin_de_travail );
-    gtk_entry_set_text ( GTK_ENTRY ( GTK_FILE_SELECTION ( fenetre_nom )->selection_entry),
-			 ".cgsb" );
+    file_selection_set_entry ( GTK_FILE_SELECTION ( fenetre_nom ), ".cgsb" );
 
     resultat = gtk_dialog_run ( GTK_DIALOG ( fenetre_nom ));
 
@@ -3082,7 +3103,7 @@ void importer_categ ( void )
 	return;
     }
 
-    nom_categ =g_strdup (gtk_file_selection_get_filename ( GTK_FILE_SELECTION ( fenetre_nom )));
+    nom_categ = file_selection_get_filename ( GTK_FILE_SELECTION ( fenetre_nom ));
 
     gtk_widget_destroy ( GTK_WIDGET (fenetre_nom  ));
 
