@@ -53,6 +53,7 @@ extern GtkWidget *widget_formulaire_echeancier[SCHEDULER_FORM_TOTAL_WIDGET];
 extern GSList *gsliste_echeances;
 extern struct operation_echeance *echeance_selectionnnee;
 extern gint nb_echeances;
+gint noname_account_number = 0;
 
 
 /* ************************************************************************** */
@@ -147,9 +148,11 @@ gint initialisation_nouveau_compte ( gint type_de_compte )
 
     p_tab_nom_de_compte_courant = p_tab_nom_de_compte + compte_courant;
 
+    noname_account_number++;
+
     /* insre ses paramtres ( comme c'est un appel  calloc, tout ce qui est  0 est dj initialis )*/
 
-    NOM_DU_COMPTE = g_strdup ( _("No name") );
+    NOM_DU_COMPTE = g_strdup_printf ( _("No name %d"), noname_account_number );
     OPERATION_SELECTIONNEE = GINT_TO_POINTER ( -1 );
     DEVISE = 1;
     MISE_A_JOUR = 1;
@@ -473,11 +476,11 @@ GtkWidget * creation_option_menu_comptes_nonclos ( GtkSignalFunc func,
 /* ************************************************************************** */
 
 /* ************************************************************************** */
-void changement_choix_compte_echeancier ( void )
+void changement_choix_compte_echeancier ( GtkWidget *item )
 {
     GtkWidget *menu;
 
-    p_tab_nom_de_compte_variable = p_tab_nom_de_compte + GPOINTER_TO_INT ( gtk_object_get_data ( GTK_OBJECT ( GTK_OPTION_MENU ( widget_formulaire_echeancier[SCHEDULER_FORM_ACCOUNT] )->menu_item),
+    p_tab_nom_de_compte_variable = p_tab_nom_de_compte + GPOINTER_TO_INT ( gtk_object_get_data ( GTK_OBJECT ( item ),
 												 "no_compte" ));
 
     if ( gtk_widget_get_style ( widget_formulaire_echeancier[SCHEDULER_FORM_CREDIT] ) == style_entree_formulaire[ENCLAIR] )
@@ -485,7 +488,7 @@ void changement_choix_compte_echeancier ( void )
 	/*       il y a qque chose dans le crdit, on met le menu des types crdit */
 
 	if ( (menu = creation_menu_types ( 2,
-					   GPOINTER_TO_INT ( gtk_object_get_data ( GTK_OBJECT ( GTK_OPTION_MENU ( widget_formulaire_echeancier[SCHEDULER_FORM_ACCOUNT] )->menu_item),
+					   GPOINTER_TO_INT ( gtk_object_get_data ( GTK_OBJECT ( item),
 										   "no_compte" )),
 					   1 )))
 	{
@@ -503,7 +506,7 @@ void changement_choix_compte_echeancier ( void )
 	/*       il y a qque chose dans le dbit ou c'est par dfaut, on met le menu des types dbit */
 
 	if ( (menu = creation_menu_types ( 1,
-					   GPOINTER_TO_INT ( gtk_object_get_data ( GTK_OBJECT ( GTK_OPTION_MENU ( widget_formulaire_echeancier[SCHEDULER_FORM_ACCOUNT] )->menu_item),
+					   GPOINTER_TO_INT ( gtk_object_get_data ( GTK_OBJECT (item ),
 										   "no_compte" )),
 					   1 )))
 	{
@@ -753,8 +756,9 @@ void update_options_menus_comptes ( void )
     /*     on met  jour l'option menu de l'chancier */
 
     gtk_option_menu_set_menu ( GTK_OPTION_MENU ( widget_formulaire_echeancier[SCHEDULER_FORM_ACCOUNT] ),
-			       creation_option_menu_comptes(GTK_SIGNAL_FUNC(changement_choix_compte_echeancier),
-							    TRUE) );
+			       creation_option_menu_comptes_nonclos (GTK_SIGNAL_FUNC(changement_choix_compte_echeancier),
+								     TRUE) );
+
 }
 /* ************************************************************************** */
 
