@@ -137,6 +137,7 @@ static struct iso_4217_currency iso_4217_currencies[] = {
     { N_("Europe"), N_("Czech Koruna"), N_("Czech Republic"), "CZK", NULL, TRUE },
     { N_("Europe"), N_("Danish Krone"), N_("Denmark"), "DKK", NULL, TRUE },
     { N_("Europe"), N_("Deutsche Mark"), N_("Germany"), "DEM", NULL, FALSE },
+    { N_("Europe"), N_("Estonian Kroon"), N_("Estonia"), "EEK", NULL, TRUE },
     { N_("Europe"), N_("Finnish Markka"), N_("Finland"), "FIM", NULL, FALSE },
     { N_("Europe"), N_("French Franc"), N_("France"), "FRF", NULL, FALSE },
     { N_("Europe"), N_("Gibraltar Pound"), N_("Gibraltar"), "GIP", NULL, TRUE },
@@ -147,6 +148,8 @@ static struct iso_4217_currency iso_4217_currencies[] = {
     { N_("Europe"), N_("Italian Lira"), N_("Holy See"), "ITL", NULL, FALSE },
     { N_("Europe"), N_("Italian Lira"), N_("Italy"), "ITL", NULL, FALSE },
     { N_("Europe"), N_("Italian Lira"), N_("San Marino"), "ITL", NULL, FALSE },
+    { N_("Europe"), N_("Latvian Lat"), N_("Latvia"), "LVL", NULL, TRUE },
+    { N_("Europe"), N_("Lithuanian Litas"), N_("Lietuva"), "LTL", NULL, TRUE },
     { N_("Europe"), N_("Luxembourg Franc"), N_("Luxembourg"), "LUF", NULL, FALSE },
     { N_("Europe"), N_("Netherlands Guilder"), N_("Netherlands"), "NLG", NULL, FALSE },
     { N_("Europe"), N_("New Yugoslavian Dinar"), N_("Serbia and Montenegro"), "YUD", NULL, FALSE },
@@ -1342,6 +1345,8 @@ gboolean change_rate_date ( GtkWidget * spin, gdouble * dummy )
     g_date_set_time ( devise -> date_dernier_change,
 		      time (NULL));
 
+    devise -> change = gtk_spin_button_get_value ( GTK_SPIN_BUTTON ( spin ));
+
     return FALSE;
 }
 
