@@ -4,6 +4,7 @@
 /*                                                                            */
 /*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org)	      */
 /*			2004 Alain Portal (dionysos@grisbi.org) 	      */
+/*			2004 Benjamin Drieu (bdrieu@april.org)  	      */
 /* 			http://www.grisbi.org   			      */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -31,6 +32,7 @@
 
 
 #include "accueil.h"
+#include "dialog.h"
 #include "barre_outils.h"
 #include "devises.h"
 #include "echeancier_formulaire.h"
@@ -61,7 +63,7 @@
 gint scheduler_col_width_ratio[NB_COLS_SCHEDULER] = { 10, 26, 20, 14, 14, 28, 8};
 gint scheduler_col_width[NB_COLS_SCHEDULER] ;
 
-void changement_taille_colonne_echeancier ( GtkWidget *clist, gint colonne, gint largeur ) ;
+gboolean changement_taille_colonne_echeancier ( GtkWidget *clist, gint colonne, gint largeur ) ;
 
 
 
@@ -255,7 +257,7 @@ GtkWidget *creation_partie_gauche_echeancier ( void )
     gtk_widget_show ( hbox );
 
     /* met un bouton valider qui est juste utilis pour faire sortir le focus de l'entre */
-
+    /* Pas de handler associ car il suffit juste de faire perdre le focus */
     bouton_valider_echeance_perso = gtk_button_new_with_label ( _("Show"));
     gtk_button_set_relief ( GTK_BUTTON ( bouton_valider_echeance_perso ),
 			    GTK_RELIEF_NONE );
@@ -275,6 +277,10 @@ GtkWidget *creation_partie_gauche_echeancier ( void )
     gtk_object_set_data ( GTK_OBJECT ( item ),
 			  "intervalle_perso",
 			  GINT_TO_POINTER ( 0 ));
+    gtk_signal_connect_object ( GTK_OBJECT ( item ),
+				"activate",
+				G_CALLBACK ( modification_affichage_echeances ),
+				GINT_TO_POINTER ( 6 ) );
     gtk_menu_append ( GTK_MENU ( menu ),
 		      item );
     gtk_widget_show ( item );
@@ -283,6 +289,10 @@ GtkWidget *creation_partie_gauche_echeancier ( void )
     gtk_object_set_data ( GTK_OBJECT ( item ),
 			  "intervalle_perso",
 			  GINT_TO_POINTER ( 1 ));
+    gtk_signal_connect_object ( GTK_OBJECT ( item ),
+				"activate",
+				G_CALLBACK ( modification_affichage_echeances ),
+				GINT_TO_POINTER ( 6 ) );
     gtk_menu_append ( GTK_MENU ( menu ),
 		      item );
     gtk_widget_show ( item );
@@ -291,16 +301,16 @@ GtkWidget *creation_partie_gauche_echeancier ( void )
     gtk_object_set_data ( GTK_OBJECT ( item ),
 			  "intervalle_perso",
 			  GINT_TO_POINTER ( 2 ));
+    gtk_signal_connect_object ( GTK_OBJECT ( item ),
+				"activate",
+				G_CALLBACK ( modification_affichage_echeances ),
+				GINT_TO_POINTER ( 6 ) );
     gtk_menu_append ( GTK_MENU ( menu ),
 		      item );
     gtk_widget_show ( item );
 
     gtk_option_menu_set_menu ( GTK_OPTION_MENU ( bouton_personnalisation_affichage_echeances ),
 			       menu );
-    gtk_signal_connect_object ( GTK_OBJECT ( GTK_OPTION_MENU ( bouton_personnalisation_affichage_echeances ) -> menu ),
-				"selection-done",
-				GTK_SIGNAL_FUNC ( modification_affichage_echeances ),
-				GINT_TO_POINTER ( 6 ) );
     gtk_box_pack_end ( GTK_BOX ( hbox ),
 		       bouton_personnalisation_affichage_echeances,
 		       FALSE,
@@ -520,12 +530,13 @@ GtkWidget *creation_liste_echeances ( void )
 					GTK_SIGNAL_FUNC ( gtk_widget_grab_focus ),
 					GTK_OBJECT ( liste_echeances ) );
 
-
 	    for ( i = 0 ; i < NB_COLS_SCHEDULER ; i++ )
 	    {
 		gtk_clist_set_column_justification ( GTK_CLIST ( liste_echeances ),
-						     i,
-						     col_justs[i] );
+						     i, col_justs[i] );
+		gtk_clist_set_column_resizeable ( GTK_CLIST ( liste_echeances ),
+						  i, TRUE );
+
 	    }
 
 	    /* dOm : rendre invisible la colonne notes */
@@ -940,17 +951,24 @@ void remplissage_liste_echeance ( void )
 }
 /*****************************************************************************/
 
-/*****************************************************************************/
-void click_ligne_echeance ( GtkCList *liste,
-			    GdkEventButton *evenement,
-			    gpointer data )
+
+
+/**
+ * Handler called upon click on the scheduled transactions list.
+ *
+ *
+ */
+gboolean click_ligne_echeance ( GtkCList *liste, GdkEventButton *evenement, gpointer data )
 {
     gint ligne, colonne, x, y;
 
+    if ( evenement -> window != liste -> clist_window )
+	return FALSE;
+
     /* si le click se situe dans les menus, c'est qu'on redimensionne, on fait rien */
 
     if ( evenement -> window != liste -> clist_window )
-	return;
+	return FALSE;
 
     gtk_signal_emit_stop_by_name ( GTK_OBJECT ( liste ),
 				   "button-press-event");
@@ -971,7 +989,7 @@ void click_ligne_echeance ( GtkCList *liste,
 
     if ( !gtk_clist_get_row_data ( GTK_CLIST ( liste ),
 				   ligne ) )
-	return;
+	return FALSE;
 
     /*   vire l'ancienne slection */
 
@@ -997,6 +1015,7 @@ void click_ligne_echeance ( GtkCList *liste,
     else
 	gtk_widget_grab_focus ( liste_echeances );
 
+    return FALSE;
 }
 /*****************************************************************************/
 
@@ -1194,43 +1213,37 @@ void edition_echeance ( void )
 	{
 	    /* 	    c'est soit un virement, soit une op ventile */
 
-	    if ( echeance_selectionnnee -> compte_virement )
+	    if ( echeance_selectionnnee -> operation_ventilee )
 	    {
+		texte =  g_strdup (_("Breakdown of transaction"));
+
+		/* 		    on n'affiche le bouton de ventilation que si on est dans l'onglet des chances, pas */
+		/* 			en formulaire flottant */
+
+		if ( !etat.formulaire_echeance_dans_fenetre ) 
+		    gtk_widget_show ( widget_formulaire_echeancier[SCHEDULER_FORM_BREAKDOWN] );
+
+		gtk_widget_set_sensitive ( widget_formulaire_echeancier[SCHEDULER_FORM_EXERCICE],
+					   FALSE );
+		gtk_widget_set_sensitive ( widget_formulaire_echeancier[SCHEDULER_FORM_BUDGETARY],
+					   FALSE );
+
+		/* met la liste des ops de ventilation dans liste_adr_ventilation */
+
+		gtk_object_set_data ( GTK_OBJECT ( formulaire_echeancier ),
+				      "liste_adr_ventilation",
+				      creation_liste_ope_de_ventil_echeances ( echeance_selectionnnee ));
+	    }
+	    else
+	    { 
+		/* 		    c'est pas une ventil, c'est donc un virement */
+
 		p_tab_nom_de_compte_variable = p_tab_nom_de_compte + echeance_selectionnnee -> compte_virement;
 
 		texte = g_strconcat ( COLON(_("Transfer")),
 				      NOM_DU_COMPTE,
 				      NULL );
 	    }
-	    else
-	    {
-		if ( echeance_selectionnnee -> operation_ventilee )
-		{
-		    texte =  g_strdup (_("Breakdown of transaction"));
-
-/* 		    on n'affiche le bouton de ventilation que si on est dans l'onglet des chances, pas */
-/* 			en formulaire flottant */
-
-		    if ( !etat.formulaire_echeance_dans_fenetre ) 
-			gtk_widget_show ( widget_formulaire_echeancier[SCHEDULER_FORM_BREAKDOWN] );
-
-		    gtk_widget_set_sensitive ( widget_formulaire_echeancier[SCHEDULER_FORM_EXERCICE],
-					       FALSE );
-		    gtk_widget_set_sensitive ( widget_formulaire_echeancier[SCHEDULER_FORM_BUDGETARY],
-					       FALSE );
-
-		    /* met la liste des ops de ventilation dans liste_adr_ventilation */
-
-		    gtk_object_set_data ( GTK_OBJECT ( formulaire_echeancier ),
-					  "liste_adr_ventilation",
-					  creation_liste_ope_de_ventil_echeances ( echeance_selectionnnee ));
-		}
-		else
-		{ 
-		    /* 		    normalement, on devrait pas arriver l... bon, on laisse comme a */
-		    texte = NULL;
-		}
-	    }
 	}
 
 	if ( texte )
@@ -1371,56 +1384,31 @@ void supprime_echeance ( struct operation_echeance *echeance )
     if ( echeance -> periodicite )
     {
 	GtkWidget *dialog;
-	GtkWidget *label;
+	gchar * occurences = "";
 
+	occurences = g_strdup_printf ( "%02d/%02d/%d : %s [%4.2f]",
+				       echeance -> jour,
+				       echeance -> mois,
+				       echeance -> annee,
+				       ( echeance -> tiers ? (((struct struct_tiers *)(g_slist_find_custom ( liste_struct_tiers,
+											GINT_TO_POINTER ( echeance -> tiers ),
+											(GCompareFunc ) recherche_tiers_par_no )->data )) -> nom_tiers) : _("No third party")),
+				       echeance -> montant );
 
-	dialog = gtk_dialog_new_with_buttons ( _("Delete a scheduled transaction maturity"),
-					       GTK_WINDOW (window),
-					       GTK_DIALOG_MODAL,
-					       _("Only this one"),0,
-					       _("All the occurences"),1,
-					       GTK_STOCK_CANCEL,2,
-					       NULL );
+	dialog = dialogue_special_no_run ( GTK_MESSAGE_QUESTION,
+					   GTK_BUTTONS_NONE,
+					   make_hint ( _("Delete a scheduled transaction"),
+						       g_strconcat ( _("Do you want to delete just this occurrence or the whole scheduled transaction?"),
+								     occurences, NULL )));
+	gtk_dialog_add_buttons ( GTK_DIALOG(dialog),
+				 GTK_STOCK_CANCEL, 2,
+				 _("All the occurences"), 1,
+				 _("Only this one"), 0,
+				 NULL );
 
-	label = gtk_label_new ( SPACIFY(_("Do you want to delete just this occurrence or the whole scheduled transaction?")) );
-	gtk_box_pack_start ( GTK_BOX ( GTK_DIALOG ( dialog ) -> vbox ),
-			     label,
-			     FALSE,
-			     FALSE,
-			     0 );
-	gtk_widget_show ( label );
-
-	if ( echeance -> tiers )
-	    label = gtk_label_new ( g_strdup_printf ( "%02d/%02d/%d : %s [%4.2f]",
-						      echeance -> jour,
-						      echeance -> mois,
-						      echeance -> annee,
-						      ((struct struct_tiers *)(g_slist_find_custom ( liste_struct_tiers,
-												     GINT_TO_POINTER ( echeance -> tiers ),
-												     (GCompareFunc ) recherche_tiers_par_no )->data )) -> nom_tiers,
-						      echeance -> montant ));
-	else
-	    label = gtk_label_new ( g_strdup_printf ( _("%02d/%02d/%d : [No third party] [%4.2f]"),
-						      echeance -> jour,
-						      echeance -> mois,
-						      echeance -> annee,
-						      echeance -> montant ));
-
-
-
-	gtk_box_pack_start ( GTK_BOX ( GTK_DIALOG ( dialog ) -> vbox ),
-			     label,
-			     FALSE,
-			     FALSE,
-			     0 );
-	gtk_widget_show ( label );
-
-
-
-	gtk_box_set_homogeneous ( GTK_BOX ( GTK_DIALOG ( dialog ) -> vbox ),
-				  TRUE );
-	gtk_dialog_set_default_response ( GTK_DIALOG ( dialog ),
-					  2 );
+/* 	gtk_box_set_homogeneous ( GTK_BOX ( GTK_DIALOG ( dialog ) -> vbox ), */
+/* 				  TRUE ); */
+	gtk_dialog_set_default_response ( GTK_DIALOG ( dialog ), 2 );
 
 	resultat = gtk_dialog_run ( GTK_DIALOG ( dialog ));
 	gtk_widget_destroy ( dialog );
@@ -1485,9 +1473,8 @@ void supprime_echeance ( struct operation_echeance *echeance )
 /*****************************************************************************/
 
 /*****************************************************************************/
-void changement_taille_colonne_echeancier ( GtkWidget *clist,
-					    gint colonne,
-					    gint largeur )
+gboolean changement_taille_colonne_echeancier ( GtkWidget *clist, gint colonne,
+						gint largeur )
 {
     gint offset ;
 
@@ -1528,6 +1515,8 @@ void changement_taille_colonne_echeancier ( GtkWidget *clist,
 
     /* on sauve la valeur de la nouvelle largeur de la colonne concerne */
     scheduler_col_width[colonne] = largeur ;
+
+    return FALSE;
 }
 /*****************************************************************************/
 
@@ -1894,7 +1883,8 @@ void verification_echeances_a_terme ( void )
 
     while ( pointeur_liste )
     {
-	if ( ECHEANCE_COURANTE -> auto_man )
+	if ( ECHEANCE_COURANTE -> auto_man &&
+	     ! ECHEANCE_COURANTE -> no_operation_ventilee_associee )
 	{
 	    /* tant que cette chance auto n'est pas arrive  aujourd'hui, on recommence */
 
@@ -1906,6 +1896,28 @@ void verification_echeances_a_terme ( void )
 		gint virement;
 		GSList *pointeur_liste_ventil;
 
+		/* We check if one of the subtransactions of the breakdown of
+		   transaction is a transfer on itself. */
+
+		pointeur_liste_ventil = creation_liste_ope_de_ventil_echeances (ECHEANCE_COURANTE);
+		while ( pointeur_liste_ventil &&
+			pointeur_liste_ventil != GINT_TO_POINTER ( -1 ))
+		{
+		    struct struct_ope_ventil *ope_ventil;
+
+		    ope_ventil = pointeur_liste_ventil -> data;
+
+		    if ( ope_ventil -> relation_no_operation &&
+			 ope_ventil -> relation_no_compte == ECHEANCE_COURANTE -> compte )
+		    {
+			dialogue_error_hint ( _("This breakdown of transaction contains a transfer on itself.  Either change the sub transaction to transfer on another account or change account of the transaction itself."),
+					      _("Can't issue scheduled operation"));
+			return;
+		    }
+
+		    pointeur_liste_ventil = pointeur_liste_ventil -> next;
+		}
+
 
 		/* cre l'opration */
 
@@ -2105,7 +2117,6 @@ void verification_echeances_a_terme ( void )
 		echeances_saisies = g_slist_append ( echeances_saisies,
 						     operation );
 
-
 		/* passe l'chance  la prochaine date */
 
 		incrementation_echeance ( ECHEANCE_COURANTE );
@@ -2119,7 +2130,7 @@ void verification_echeances_a_terme ( void )
 		}
 	    }
 	}
-	else
+	else if ( ! ECHEANCE_COURANTE -> no_operation_ventilee_associee )
 	    /* ce n'est pas une chance automatique, on la rpertorie dans la liste des chances  saisir */
 
 	    if ( g_date_compare ( ECHEANCE_COURANTE -> date,
@@ -2170,8 +2181,7 @@ void verifie_ligne_selectionnee_echeance_visible ( void )
 /* Fonction appele lorsqu'on change le bouton pour l'affichage des	     */
 /* chances ( choix mois, 2 mois ... )					     */
 /*****************************************************************************/
-gboolean modification_affichage_echeances ( gint *origine, GdkEventFocus * event,
-					    GtkWidget * widget )
+gboolean modification_affichage_echeances ( gint *origine, GtkWidget * widget )
 {
     switch ( GPOINTER_TO_INT ( origine ))
     {
@@ -2187,8 +2197,8 @@ gboolean modification_affichage_echeances ( gint *origine, GdkEventFocus * event
 
 	case 6:
 
-	    affichage_echeances_perso_j_m_a = GPOINTER_TO_INT ( gtk_object_get_data ( GTK_OBJECT ( GTK_OPTION_MENU ( bouton_personnalisation_affichage_echeances ) -> menu_item ),
-										      "intervalle_perso" ));
+	    affichage_echeances_perso_j_m_a = GPOINTER_TO_INT 
+		( gtk_object_get_data ( GTK_OBJECT ( widget ), "intervalle_perso" ));
 	    break;
 
 	    /*       vient du reste, si c'est perso ( 4 ) , on affiche ce qu'il faut */
