@@ -399,22 +399,7 @@ GtkWidget *creation_fenetre_equilibrage ( void )
 		       0);
     gtk_widget_show ( hbox );
 
-    bouton_ok_equilibrage = gtk_button_new_with_label (_("Valid") );
-    gtk_button_set_relief ( GTK_BUTTON ( bouton_ok_equilibrage),
-			    GTK_RELIEF_NONE);
-    gtk_signal_connect ( GTK_OBJECT ( bouton_ok_equilibrage ),
-			 "clicked",
-			 ( GtkSignalFunc ) fin_equilibrage,
-			 NULL );
-    gtk_box_pack_start ( GTK_BOX ( hbox ),
-			 bouton_ok_equilibrage,
-			 FALSE,
-			 FALSE,
-			 0);
-    gtk_widget_show ( bouton_ok_equilibrage );
-
-
-    bouton = gtk_button_new_with_label (_("Cancel") );
+    bouton = gtk_button_new_from_stock ( GTK_STOCK_CANCEL );
     gtk_button_set_relief ( GTK_BUTTON ( bouton),
 			    GTK_RELIEF_NONE);
     gtk_signal_connect ( GTK_OBJECT (bouton),
@@ -428,6 +413,19 @@ GtkWidget *creation_fenetre_equilibrage ( void )
 			 0);
     gtk_widget_show ( bouton );
 
+    bouton_ok_equilibrage = gtk_button_new_from_stock ( GTK_STOCK_OK );
+    gtk_button_set_relief ( GTK_BUTTON ( bouton_ok_equilibrage),
+			    GTK_RELIEF_NONE);
+    gtk_signal_connect ( GTK_OBJECT ( bouton_ok_equilibrage ),
+			 "clicked",
+			 ( GtkSignalFunc ) fin_equilibrage,
+			 NULL );
+    gtk_box_pack_start ( GTK_BOX ( hbox ),
+			 bouton_ok_equilibrage,
+			 FALSE,
+			 FALSE,
+			 0);
+    gtk_widget_show ( bouton_ok_equilibrage );
 
     separateur = gtk_hseparator_new();
     gtk_box_pack_end ( GTK_BOX ( fenetre_equilibrage ),
@@ -449,13 +447,6 @@ void equilibrage ( void )
 
     p_tab_nom_de_compte_variable = p_tab_nom_de_compte_courant;
 
-    if ( !NB_OPE_COMPTE )
-    {
-	dialogue_error ( _("This account does not contain any transaction") );
-	return;
-    }
-
-
     /* efface le label proprits du compte */
 
     gtk_widget_hide ( label_proprietes_operations_compte );
@@ -787,6 +778,19 @@ void pointe_equilibrage ( int p_ligne )
 {
     struct structure_operation *operation;
     gdouble montant;
+    gint i, j, col = -1;
+
+    for ( i=0 ; i<4 ; i++ )
+    {
+      for ( j=0 ; j<7 ; j++ )
+      {
+	if ( tab_affichage_ope[i][j] == 13 )
+	  col = j;
+      }
+    }
+
+    if ( col == -1 )
+      return;
 
     operation = gtk_clist_get_row_data ( GTK_CLIST ( CLIST_OPERATIONS ),
 					 p_ligne );
@@ -819,7 +823,7 @@ void pointe_equilibrage ( int p_ligne )
 
 	gtk_clist_set_text ( GTK_CLIST ( CLIST_OPERATIONS ),
 			     p_ligne,
-			     3,
+			     col,
 			     " ");
     }
     else
@@ -831,7 +835,7 @@ void pointe_equilibrage ( int p_ligne )
 
 	gtk_clist_set_text ( GTK_CLIST ( CLIST_OPERATIONS ),
 			     p_ligne,
-			     3,
+			     col,
 			     _("P"));
     }
 
@@ -1161,7 +1165,7 @@ gboolean clavier_equilibrage ( GtkWidget *widget,
 
 	    gtk_signal_emit_stop_by_name ( GTK_OBJECT ( widget ),
 					   "key-press-event");
-	    if ( ( event -> state & GDK_SHIFT_MASK ) != GDK_SHIFT_MASK )
+	    if ( ( event -> state & GDK_SHIFT_MASK ) != GDK_SHIFT_MASK || event -> keyval != GDK_KP_Add )
 		inc_dec_date ( widget, ONE_DAY );
 	    else
 		inc_dec_date ( widget, ONE_WEEK );
@@ -1173,7 +1177,7 @@ gboolean clavier_equilibrage ( GtkWidget *widget,
 
 	    gtk_signal_emit_stop_by_name ( GTK_OBJECT ( widget ),
 					   "key-press-event");
-	    if ( ( event -> state & GDK_SHIFT_MASK ) != GDK_SHIFT_MASK )
+	    if ( ( event -> state & GDK_SHIFT_MASK ) != GDK_SHIFT_MASK || event -> keyval != GDK_KP_Subtract )
 		inc_dec_date ( widget, - ONE_DAY );
 	    else
 		inc_dec_date ( widget, - ONE_WEEK );
