@@ -26,6 +26,7 @@
 
 #include "devises.h"
 #include "etats_gtktable.h"
+#include "etats_html.h"
 #include "etats_latex.h"
 #include "etats_affiche.h"
 #include "search_glist.h"
@@ -817,8 +818,6 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 							g_date_year ( date_jour ) );
 			    g_date_subtract_months ( date_tmp,
 						     3 );
-			    g_date_subtract_months ( date_jour,
-						     1 );
 			    if ( g_date_compare ( date_tmp,
 						  operation -> date ) > 0
 				 ||
@@ -835,8 +834,6 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 							g_date_year ( date_jour ) );
 			    g_date_subtract_months ( date_tmp,
 						     6 );
-			    g_date_subtract_months ( date_jour,
-						     1 );
 			    if ( g_date_compare ( date_tmp,
 						  operation -> date ) > 0
 				 ||
@@ -853,8 +850,6 @@ GSList *recupere_opes_etat ( struct struct_etat *etat )
 							g_date_year ( date_jour ) );
 			    g_date_subtract_months ( date_tmp,
 						     12 );
-			    g_date_subtract_months ( date_jour,
-						     1 );
 			    if ( g_date_compare ( date_tmp,
 						  operation -> date ) > 0
 				 ||
@@ -1496,6 +1491,25 @@ void impression_etat_courant ( )
 }
 
 
+
+
+void export_etat_vers_html ( struct struct_etat *etat )
+{
+    affichage_etat ( etat, &html_affichage );
+}
+
+
+
+void export_etat_courant_vers_html ( )
+{
+    if ( gtk_notebook_get_current_page ( GTK_NOTEBOOK ( notebook_general)) != 7 )
+	gtk_notebook_set_page ( GTK_NOTEBOOK ( notebook_general),
+				7 );
+
+    export_etat_vers_html ( NULL );
+}
+
+
 /*****************************************************************************************************/
 /* Fonction de classement de la liste */
 /* en fonction du choix du type de classement */
@@ -1516,11 +1530,8 @@ classement_suivant:
 
     if ( !pointeur )
     {
-	if ( etat_courant -> afficher_opes )
-	    return ( classement_ope_perso_etat ( operation_1,
-						 operation_2 ));
-	else
-	    return (-1);
+	return ( classement_ope_perso_etat ( operation_1, operation_2 ));
+
     }
 
     switch ( GPOINTER_TO_INT ( pointeur -> data ))
