@@ -33,6 +33,8 @@
 #include "tiers_onglet.h"
 #include "traitement_variables.h"
 #include "utils.h"
+#include "utils_files.h"
+#include "utils_file_selection.h"
 
 GtkWidget *paned_onglet_etats;
 
@@ -301,7 +303,10 @@ GtkWidget *creation_liste_etats ( void )
 							   menu_name(_("Reports"), _("Print report"), NULL)),
 			       FALSE );
     gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
-							   menu_name(_("Reports"), _("Export report"), NULL)),
+							   menu_name(_("Reports"), _("Export report file"), NULL)),
+			       FALSE );
+    gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
+							   menu_name(_("Reports"), _("Export report as HTML..."), NULL)),
 			       FALSE );
     gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
 							   menu_name(_("Reports"), _("Remove report"), NULL)),
@@ -1071,7 +1076,10 @@ void efface_etat ( void )
 							   menu_name(_("Reports"), _("Print report"), NULL)),
 			       FALSE );
     gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
-							   menu_name(_("Reports"), _("Export report"), NULL)),
+							   menu_name(_("Reports"), _("Export report as HTML..."), NULL)),
+			       FALSE );
+    gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
+							   menu_name(_("Reports"), _("Export report file"), NULL)),
 			       FALSE );
     gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
 							   menu_name(_("Reports"), _("Remove report"), NULL)),
@@ -1113,7 +1121,10 @@ void changement_etat ( GtkWidget *bouton,
 							   menu_name(_("Reports"), _("Print report"), NULL)),
 			       TRUE );
     gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
-							   menu_name(_("Reports"), _("Export report"), NULL)),
+							   menu_name(_("Reports"), _("Export report as HTML..."), NULL)),
+			       TRUE );
+    gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
+							   menu_name(_("Reports"), _("Export report file"), NULL)),
 			       TRUE );
     gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
 							   menu_name(_("Reports"), _("Remove report"), NULL)),
@@ -1146,18 +1157,18 @@ void exporter_etat ( void )
 				7 );
 
     fenetre_nom = gtk_file_selection_new (_("Export report") );
-    gtk_file_selection_set_filename ( GTK_FILE_SELECTION ( fenetre_nom ),
-				      dernier_chemin_de_travail );
-    gtk_entry_set_text ( GTK_ENTRY ( GTK_FILE_SELECTION ( fenetre_nom )->selection_entry),
-			 g_strconcat ( etat_courant -> nom_etat,
-				       ".egsb",
-				       NULL ));
+    file_selection_set_filename ( GTK_FILE_SELECTION ( fenetre_nom ),
+				  dernier_chemin_de_travail );
+    file_selection_set_entry (  GTK_FILE_SELECTION ( fenetre_nom ),
+				g_strconcat ( safe_file_name ( etat_courant -> nom_etat ),
+					      ".egsb",
+					      NULL ));
     resultat = gtk_dialog_run ( GTK_DIALOG ( fenetre_nom ));
 
     switch ( resultat )
     {
 	case GTK_RESPONSE_OK :
-	    nom_etat =g_strdup (gtk_file_selection_get_filename ( GTK_FILE_SELECTION ( fenetre_nom )));
+	    nom_etat = file_selection_get_filename ( GTK_FILE_SELECTION ( fenetre_nom ));
 
 	    gtk_widget_destroy ( GTK_WIDGET ( fenetre_nom ));
 
@@ -1166,7 +1177,7 @@ void exporter_etat ( void )
 	    if ( !strlen ( nom_etat ))
 		return;
 
-	    if ( stat ( nom_etat,
+	    if ( utf8_stat ( nom_etat,
 			&test_fichier ) != -1 )
 	    {
 		if ( S_ISREG ( test_fichier.st_mode ) )
@@ -1211,9 +1222,9 @@ void importer_etat ( void )
 				7 );
 
     fenetre_nom = gtk_file_selection_new ( _("Import a report"));
-    gtk_file_selection_set_filename ( GTK_FILE_SELECTION ( fenetre_nom ),
+    file_selection_set_filename ( GTK_FILE_SELECTION ( fenetre_nom ),
 				      dernier_chemin_de_travail );
-    gtk_entry_set_text ( GTK_ENTRY ( GTK_FILE_SELECTION ( fenetre_nom )->selection_entry),
+    file_selection_set_entry ( GTK_FILE_SELECTION ( fenetre_nom ),
 			 g_strconcat ( dernier_chemin_de_travail,
 				       ".egsb",
 				       NULL ));
@@ -1223,7 +1234,7 @@ void importer_etat ( void )
     switch ( resultat )
     {
 	case GTK_RESPONSE_OK :
-	    nom_etat =g_strdup (gtk_file_selection_get_filename ( GTK_FILE_SELECTION ( fenetre_nom )));
+	    nom_etat = file_selection_get_filename ( GTK_FILE_SELECTION ( fenetre_nom ));
 
 	    gtk_widget_destroy ( GTK_WIDGET ( fenetre_nom ));
 
