@@ -40,6 +40,7 @@
 #include "patienter.h"
 #include "type_operations.h"
 #include "utils.h"
+#include "utils_files.h"
 #include "constants.h"
 
 
@@ -58,24 +59,24 @@ extern GtkWidget *paned_onglet_etats;
 void charge_configuration ( void )
 {
     xmlDocPtr doc;
-    xmlNodePtr node;
+    xmlNodePtr node, root;
     struct stat buffer_stat;
 
     raz_configuration ();
 
-    if ( stat ( g_strconcat ( my_get_grisbirc_dir(), C_GRISBIRC, NULL ),&buffer_stat ) == -1 )
+    if ( utf8_stat ( g_strconcat ( my_get_grisbirc_dir(), C_GRISBIRC, NULL ),&buffer_stat ) == -1 )
     {
 #ifndef _WIN32 /* No old configuration under Windows */
-	if (  stat ( g_strconcat ( my_get_grisbirc_dir(), "/.gnome/Grisbi", NULL ),&buffer_stat ) != -1 )
+	if (  utf8_stat ( g_strconcat ( my_get_grisbirc_dir(), "/.gnome/Grisbi", NULL ),&buffer_stat ) != -1 )
 	    charge_configuration_ancien();
 #endif
 	return;
     }
 
-    doc = xmlParseFile ( g_strconcat ( my_get_grisbirc_dir(), C_GRISBIRC, NULL ) );
+    doc = utf8_xmlParseFile ( g_strconcat ( my_get_grisbirc_dir(), C_GRISBIRC, NULL ) );
 
     /* vrifications d'usage */
-    xmlNodePtr root = xmlDocGetRootElement(doc);
+    root = xmlDocGetRootElement(doc);
 
     if ( !root
 	 ||
@@ -199,13 +200,14 @@ void charge_configuration ( void )
 		}
 		if ( !strcmp ( node_io -> name, "Compression_fichier" ) ) {
 		    compression_fichier = my_atoi(xmlNodeGetContent ( node_io));
+		    xmlSetCompressMode ( compression_fichier );
 		}
 		if ( !strcmp ( node_io -> name, "Compression_backup" ) ) {
 		    compression_backup = my_atoi(xmlNodeGetContent ( node_io));
 		}
 		if ( !strcmp ( node_io->name, "Liste_noms_derniers_fichiers_ouverts" ) ) {
-		    nb_derniers_fichiers_ouverts = 0;
 		    xmlNodePtr node_filename = node_io -> children;
+		    nb_derniers_fichiers_ouverts = 0;
 		    tab_noms_derniers_fichiers_ouverts = malloc ( nb_max_derniers_fichiers_ouverts * sizeof(gchar *) );
 		    while ( node_filename ) {
 			if ( !strcmp ( node_filename -> name, "fichier" ) ) {
@@ -400,7 +402,7 @@ void charge_configuration_ancien ( void )
 				 "/.gnome/Grisbi",
 				 NULL );
 
-    fichier = fopen ( fichier_conf,
+    fichier = utf8_fopen ( fichier_conf,
 		      "ro" );
     if ( !fichier )
     {
@@ -611,7 +613,11 @@ void raz_configuration ( void )
 
     /* Print */
     etat.print_config.printer = 0;
+#ifndef _WIN32
     etat.print_config.printer_name = "lpr";
+#else
+    etat.print_config.printer_name = "gsprint";
+#endif
     etat.print_config.printer_filename = "";
     etat.print_config.filetype = POSTSCRIPT_FILE;
     etat.print_config.paper_config.name = _("A4");
@@ -788,7 +794,7 @@ void sauve_configuration(void)
 
 
     /* Enregistre dans le ~/.grisbirc */
-    resultat = xmlSaveFormatFile ( g_strconcat ( my_get_grisbirc_dir(), C_GRISBIRC,
+    resultat = utf8_xmlSaveFormatFile ( g_strconcat ( my_get_grisbirc_dir(), C_GRISBIRC,
 						 NULL), doc, 1 );
 
     /* on libre la memoire */
