@@ -27,9 +27,6 @@
 #include "structures.h"
 #include "variables-extern.c"
 #include "fichiers_gestion.h"
-
-
-
 #include "accueil.h"
 #include "categories_onglet.h"
 #include "comptes_traitements.h"
@@ -44,7 +41,8 @@
 #include "traitement_variables.h"
 #include "fichier_configuration.h"
 #include "utils.h"
-
+#include "utils_files.h"
+#include "utils_file_selection.h"
 
 extern GtkWidget *window_vbox_principale;
 extern gint patience_en_cours;
@@ -114,10 +112,6 @@ void nouveau_fichier ( void )
 
     creation_listes_operations ();
 
-    p_tab_nom_de_compte_variable = p_tab_nom_de_compte_courant;
-
-    changement_compte ( GINT_TO_POINTER ( compte_courant ) );
-
 
     /* affiche le nom du fichier de comptes dans le titre de la fenetre */
 
@@ -125,6 +119,14 @@ void nouveau_fichier ( void )
 
     gtk_widget_show ( notebook_general );
 
+    /*     ncessaire pour viter un non affichage de l'acceuil dans certains cas */
+
+    while ( g_main_iteration (FALSE));
+
+    p_tab_nom_de_compte_variable = p_tab_nom_de_compte_courant;
+
+    changement_compte ( GINT_TO_POINTER ( compte_courant ) );
+
     /* on se met sur l'onglet de proprits du compte */
 
     gtk_notebook_set_page ( GTK_NOTEBOOK ( notebook_general ),
@@ -144,7 +146,7 @@ void ouvrir_fichier ( void )
     gtk_window_set_position ( GTK_WINDOW ( selection_fichier ),
 			      GTK_WIN_POS_MOUSE);
 
-    gtk_file_selection_set_filename ( GTK_FILE_SELECTION ( selection_fichier ),
+    file_selection_set_filename ( GTK_FILE_SELECTION ( selection_fichier ),
 				      dernier_chemin_de_travail );
 
     gtk_signal_connect_object ( GTK_OBJECT ( GTK_FILE_SELECTION ( selection_fichier ) -> cancel_button ),
@@ -201,15 +203,13 @@ void fichier_selectionne ( GtkWidget *selection_fichier)
 
     /* on prend le nouveau nom du fichier */
 
-    nom_fichier_comptes = g_strdup ( gtk_file_selection_get_filename ( GTK_FILE_SELECTION ( selection_fichier)) );
+    nom_fichier_comptes = file_selection_get_filename ( GTK_FILE_SELECTION ( selection_fichier)) ;
 
     gtk_widget_hide ( selection_fichier );
 
     /* on met le rpertoire courant dans la variable correspondante */
 
-    dernier_chemin_de_travail = g_strconcat ( GTK_LABEL ( GTK_BIN ( GTK_OPTION_MENU ( GTK_FILE_SELECTION ( selection_fichier ) -> history_pulldown )) -> child ) -> label,
-					      C_DIRECTORY_SEPARATOR,
-					      NULL );
+    dernier_chemin_de_travail = file_selection_get_last_directory( GTK_FILE_SELECTION (selection_fichier),TRUE);
 
     ouverture_confirmee ();
 }
@@ -262,7 +262,7 @@ void ouverture_confirmee ( void )
 						    NULL );
 		g_strfreev ( parametres );
 
-		result = open ( nom_fichier_comptes, O_RDONLY);
+		result = utf8_open ( nom_fichier_comptes, O_RDONLY);
 		if (result == -1)
 		    return;
 		else
@@ -309,14 +309,17 @@ void ouverture_confirmee ( void )
 		/* 	      on rcupre uniquement le nom du fichier, pas le chemin */
 
 		parametres = g_strsplit ( nom_fichier_comptes,
-					  "/",
+					  C_DIRECTORY_SEPARATOR,
 					  0);
 
 		while ( parametres[i] )
 		    i++;
 
 		nom_fichier_comptes = g_strconcat ( my_get_gsb_file_default_dir(),
-						    "/.",
+						    C_DIRECTORY_SEPARATOR,
+#ifndef _WIN32
+                                                    ".",
+#endif
 						    parametres [i-1],
 						    ".bak",
 						    NULL );
@@ -417,10 +420,12 @@ gboolean enregistrement_fichier ( gint origine )
 
     etat_force = 0;
 
-    if ( !etat.modification_fichier && origine != -2 )
+    if ( ( ! etat.modification_fichier && origine != -2 ) ||
+	 ! nb_comptes )
 	return ( TRUE );
 
-    if ( origine == -1 )
+    if ( origine == -1 &&
+	 (!etat.sauvegarde_auto || !nom_fichier_comptes) )
     {
 	gchar * hint;
 
@@ -437,6 +442,7 @@ gboolean enregistrement_fichier ( gint origine )
 				 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				 GTK_STOCK_SAVE, GTK_RESPONSE_OK,
 				 NULL );
+	gtk_dialog_set_default_response ( GTK_DIALOG(dialog), GTK_RESPONSE_OK ); 
 	gtk_label_set_markup ( GTK_LABEL ( GTK_MESSAGE_DIALOG(dialog)->label ), 
 			       make_hint ( hint, _("If you close without saving, all of your changes will be discarded.")) );
 
@@ -469,10 +475,9 @@ gboolean enregistrement_fichier ( gint origine )
 	fenetre_nom = gtk_file_selection_new ( _("Name the accounts file"));
 	gtk_window_set_modal ( GTK_WINDOW ( fenetre_nom ),
 			       TRUE );
-	gtk_file_selection_set_filename ( GTK_FILE_SELECTION ( fenetre_nom ),
+	file_selection_set_filename ( GTK_FILE_SELECTION ( fenetre_nom ),
 					  dernier_chemin_de_travail );
-	gtk_entry_set_text ( GTK_ENTRY ( GTK_FILE_SELECTION ( fenetre_nom )->selection_entry),
-			     ".gsb" );
+        file_selection_set_entry (GTK_FILE_SELECTION ( fenetre_nom ), ".gsb");
 
 	resultat = gtk_dialog_run ( GTK_DIALOG ( fenetre_nom ));
 
@@ -480,7 +485,7 @@ gboolean enregistrement_fichier ( gint origine )
 	{
 	    case GTK_RESPONSE_OK :
 		ancien_nom_fichier_comptes = nom_fichier_comptes;
-		nom_fichier_comptes =g_strdup (gtk_file_selection_get_filename ( GTK_FILE_SELECTION ( fenetre_nom )));
+		nom_fichier_comptes = file_selection_get_filename ( GTK_FILE_SELECTION ( fenetre_nom ));
 
 		gtk_widget_destroy ( GTK_WIDGET ( fenetre_nom ));
 
@@ -493,7 +498,7 @@ gboolean enregistrement_fichier ( gint origine )
 		}
 
 
-		if ( stat ( nom_fichier_comptes,
+		if ( utf8_stat ( nom_fichier_comptes,
 			    &test_fichier ) != -1 )
 		{
 		    if ( S_ISREG ( test_fichier.st_mode ) )
@@ -531,7 +536,6 @@ gboolean enregistrement_fichier ( gint origine )
 	    etat.force_enregistrement = 1;
     }
 
-
     if ( nom_fichier_backup && strlen(nom_fichier_backup) )
 	if ( !enregistrement_backup() )
 	    return ( FALSE );
@@ -831,7 +835,7 @@ void ajoute_nouveau_fichier_liste_ouverture ( gchar *path_fichier )
 	tab_noms_derniers_fichiers_ouverts[nb_derniers_fichiers_ouverts-1] = dernier;
     }
 
-    tab_noms_derniers_fichiers_ouverts[0] = g_strdup ( path_fichier );
+    tab_noms_derniers_fichiers_ouverts[0] = g_strdup (path_fichier);
 
 
     affiche_derniers_fichiers_ouverts();
