@@ -43,6 +43,8 @@
 #include "tiers_onglet.h"
 #include "traitement_variables.h"
 #include "utils.h"
+#include "utils_files.h"
+#include "utils_file_selection.h"
 
 
 extern GSList *gsliste_echeances; 
@@ -1656,7 +1658,7 @@ void supprimer_imputation ( void )
 
 		    sous_imputation = sous_pointeur -> data;
 
-		    if ( imputation -> type_imputation )
+		    if ( imputation_tmp -> type_imputation )
 			liste_imputation_debit = g_slist_append ( liste_imputation_debit,
 								  g_strconcat ( "\t",
 										sous_imputation -> nom_sous_imputation,
@@ -1980,21 +1982,21 @@ void supprimer_sous_imputation ( void )
 
 	    while ( sous_pointeur )
 	    {
-		struct struct_sous_imputation *sous_imputation;
+		struct struct_sous_imputation *sous_imputation_tmp;
 
-		sous_imputation = sous_pointeur -> data;
+		sous_imputation_tmp = sous_pointeur -> data;
 
-		if ( sous_imputation -> no_sous_imputation !=  sous_imputation -> no_sous_imputation )
+		if ( sous_imputation_tmp -> no_sous_imputation != sous_imputation -> no_sous_imputation )
 		{
 		    if ( imputation -> type_imputation )
 			liste_imputation_debit = g_slist_append ( liste_imputation_debit,
 								  g_strconcat ( "\t",
-										sous_imputation -> nom_sous_imputation,
+										sous_imputation_tmp -> nom_sous_imputation,
 										NULL ) );
 		    else
 			liste_imputation_credit = g_slist_append ( liste_imputation_credit,
 								   g_strconcat ( "\t",
-										 sous_imputation -> nom_sous_imputation,
+										 sous_imputation_tmp -> nom_sous_imputation,
 										 NULL ) );
 		}
 		sous_pointeur = sous_pointeur -> next;
@@ -2309,8 +2311,17 @@ struct struct_imputation *ajoute_nouvelle_imputation ( gchar *imputation )
 {
     struct struct_imputation *nouvelle_imputation;
 
-    nouvelle_imputation = calloc ( 1,
-				   sizeof ( struct struct_imputation ));
+    if ( g_slist_find_custom ( liste_struct_imputation,
+			       imputation,
+			       (GCompareFunc) recherche_imputation_par_nom ) )
+      {
+	dialogue_warning_hint ( _("Budgetary lines names must be both unique and not empty.  Please use another name for this budgetary line."),
+				g_strdup_printf ( _("Budgetary line '%s' already exists."),
+						  imputation ) );
+	return NULL;
+      }
+
+    nouvelle_imputation = calloc ( 1, sizeof ( struct struct_imputation ));
 
     nouvelle_imputation -> no_imputation = ++no_derniere_imputation;
     nouvelle_imputation -> nom_imputation = g_strdup ( g_strstrip ( imputation ));
@@ -2341,6 +2352,17 @@ struct struct_sous_imputation *ajoute_nouvelle_sous_imputation ( gchar *sous_imp
     nouvelle_sous_imputation = malloc ( sizeof ( struct struct_sous_imputation ));
 
     nouvelle_sous_imputation -> no_sous_imputation = ++( imputation->no_derniere_sous_imputation );
+
+    if ( g_slist_find_custom ( imputation -> liste_sous_imputation,
+			       sous_imputation,
+			       (GCompareFunc) recherche_sous_imputation_par_nom ) )
+      {
+	dialogue_warning_hint ( _("Sub-budgetary lines names must be both unique and not empty.  Please use another name for this sub-budgetary line."),
+				g_strdup_printf ( _("Sub-budgetary line '%s' already exists."),
+						  sous_imputation ) );
+	return NULL;
+      }
+
     nouvelle_sous_imputation -> nom_sous_imputation = g_strdup ( g_strstrip ( sous_imputation ));
 
     imputation -> liste_sous_imputation = g_slist_append ( imputation -> liste_sous_imputation,
@@ -2386,14 +2408,15 @@ void fusion_categories_imputation ( void )
 	    /* 	  l'imputation n'existe pas, on la cre */
 
 	    imputation = ajoute_nouvelle_imputation ( categorie -> nom_categ );
-	    imputation -> type_imputation = categorie -> type_categ;
+	    if ( imputation )
+	      imputation -> type_imputation = categorie -> type_categ;
 	}
 
 	/* on fait maintenant la comparaison avec les sous catg et les sous imputations */
 
 	liste_sous_tmp = categorie -> liste_sous_categ;
 
-	while ( liste_sous_tmp )
+	while ( liste_sous_tmp && imputation )
 	{
 	    struct struct_sous_categ *sous_categ;
 
@@ -2480,56 +2503,61 @@ void calcule_total_montant_imputation ( void )
 	    if ( operation -> imputation )
 	    {
 		struct struct_imputation *imputation;
+		GSList * occurence;
 
 		/* il y a une catgorie */
 
-		imputation = g_slist_find_custom ( liste_struct_imputation,
-						   GINT_TO_POINTER ( operation -> imputation ),
-						   (GCompareFunc) recherche_imputation_par_no ) -> data;
-
-		/* recherche la place du tiers dans la liste */
-
-		place_imputation = g_slist_index ( liste_struct_imputation,
-						   imputation );
-
-		/* cre la place pour les sous catg de cette imputation si ce n'est dj fait */
-
-		if ( !tab_montant_sous_imputation[place_imputation] )
+		occurence = g_slist_find_custom ( liste_struct_imputation,
+						  GINT_TO_POINTER ( operation -> imputation ),
+						  (GCompareFunc) recherche_imputation_par_no );
+		if ( occurence )
 		{
-		    gint nb_sous_imputation;
+		    imputation = occurence -> data;
 
-		    nb_sous_imputation = g_slist_length ( imputation -> liste_sous_imputation );
+		    /* recherche la place du tiers dans la liste */
 
-		    /* on rserve nb_sous_imputation + 1 pour aucune sous imputation qui sera en [0] */
+		    place_imputation = g_slist_index ( liste_struct_imputation,
+						       imputation );
 
-		    tab_montant_sous_imputation[place_imputation] = calloc ( nb_sous_imputation + 1,
-									     sizeof ( float ));
-		    nb_ecritures_par_sous_imputation[place_imputation] = calloc ( nb_sous_imputation + 1,
-										  sizeof ( gint ));
-		}
+		    /* cre la place pour les sous catg de cette imputation si ce n'est dj fait */
 
-		tab_montant_imputation[place_imputation+1] = tab_montant_imputation[place_imputation+1] + montant;
-		nb_ecritures_par_imputation[place_imputation+1]++;
-
-		/* on ajoute maintenant le montant  la sous imputation si elle existe */
-
-		if ( operation -> sous_imputation )
-		{
-		    gint place_sous_imputation;
-
-		    place_sous_imputation = g_slist_position ( imputation -> liste_sous_imputation,
-							       g_slist_find_custom ( imputation -> liste_sous_imputation,
-										     GINT_TO_POINTER ( operation -> sous_imputation ),
-										     (GCompareFunc) recherche_sous_imputation_par_no ));
-		    tab_montant_sous_imputation[place_imputation][place_sous_imputation+1] = tab_montant_sous_imputation[place_imputation][place_sous_imputation+1] + montant;
-		    nb_ecritures_par_sous_imputation[place_imputation][place_sous_imputation+1]++;
-		}
-		else
-		{
-		    if ( tab_montant_sous_imputation[place_imputation] )
+		    if ( !tab_montant_sous_imputation[place_imputation] )
 		    {
-			tab_montant_sous_imputation[place_imputation][0] = tab_montant_sous_imputation[place_imputation][0] + montant;
-			nb_ecritures_par_sous_imputation[place_imputation][0]++;
+			gint nb_sous_imputation;
+
+			nb_sous_imputation = g_slist_length ( imputation -> liste_sous_imputation );
+
+			/* on rserve nb_sous_imputation + 1 pour aucune sous imputation qui sera en [0] */
+
+			tab_montant_sous_imputation[place_imputation] = calloc ( nb_sous_imputation + 1,
+										 sizeof ( float ));
+			nb_ecritures_par_sous_imputation[place_imputation] = calloc ( nb_sous_imputation + 1,
+										      sizeof ( gint ));
+		    }
+
+		    tab_montant_imputation[place_imputation+1] = tab_montant_imputation[place_imputation+1] + montant;
+		    nb_ecritures_par_imputation[place_imputation+1]++;
+
+		    /* on ajoute maintenant le montant  la sous imputation si elle existe */
+
+		    if ( operation -> sous_imputation )
+		    {
+			gint place_sous_imputation;
+
+			place_sous_imputation = g_slist_position ( imputation -> liste_sous_imputation,
+								   g_slist_find_custom ( imputation -> liste_sous_imputation,
+											 GINT_TO_POINTER ( operation -> sous_imputation ),
+											 (GCompareFunc) recherche_sous_imputation_par_no ));
+			tab_montant_sous_imputation[place_imputation][place_sous_imputation+1] = tab_montant_sous_imputation[place_imputation][place_sous_imputation+1] + montant;
+			nb_ecritures_par_sous_imputation[place_imputation][place_sous_imputation+1]++;
+		    }
+		    else
+		    {
+			if ( tab_montant_sous_imputation[place_imputation] )
+			{
+			    tab_montant_sous_imputation[place_imputation][0] = tab_montant_sous_imputation[place_imputation][0] + montant;
+			    nb_ecritures_par_sous_imputation[place_imputation][0]++;
+			}
 		    }
 		}
 	    }
@@ -2618,6 +2646,8 @@ void appui_sur_ajout_imputation ( void )
 
     nouvelle_imputation = ajoute_nouvelle_imputation ( nom_imputation );
 
+    if ( ! nouvelle_imputation )
+      return;
 
     /* on l'ajoute directement au ctree et on fait le tri pour viter de toute la rafficher */
 
@@ -2686,8 +2716,11 @@ void appui_sur_ajout_sous_imputation ( void )
     nouvelle_sous_imputation = ajoute_nouvelle_sous_imputation ( nom_sous_imputation,
 								 imputation );
 
+    if ( ! nouvelle_sous_imputation )
+      return;
 
-    /* on l'ajoute directement au ctree et on fait le tri pour viter de toute la rafficher */
+    /* on l'ajoute directement au ctree et on fait le tri pour viter
+       de toute la rafficher */
 
     text[0] = nouvelle_sous_imputation -> nom_sous_imputation;
     text[1] = NULL;
@@ -2733,16 +2766,15 @@ void exporter_ib ( void )
     gchar *nom_ib;
 
     fenetre_nom = gtk_file_selection_new (  _("Export the budgetary lines"));
-    gtk_file_selection_set_filename ( GTK_FILE_SELECTION ( fenetre_nom ),
+    file_selection_set_filename ( GTK_FILE_SELECTION ( fenetre_nom ),
 				      dernier_chemin_de_travail );
-    gtk_entry_set_text ( GTK_ENTRY ( GTK_FILE_SELECTION ( fenetre_nom )->selection_entry),
-			 ".igsb" );
+    file_selection_set_entry ( GTK_FILE_SELECTION ( fenetre_nom ), ".igsb" );
     resultat = gtk_dialog_run ( GTK_DIALOG ( fenetre_nom ));
 
     switch ( resultat )
     {
 	case GTK_RESPONSE_OK :
-	    nom_ib =g_strdup (gtk_file_selection_get_filename ( GTK_FILE_SELECTION ( fenetre_nom )));
+	    nom_ib = file_selection_get_filename ( GTK_FILE_SELECTION ( fenetre_nom ));
 
 	    gtk_widget_destroy ( GTK_WIDGET ( fenetre_nom ));
 
@@ -2751,7 +2783,7 @@ void exporter_ib ( void )
 	    if ( !strlen ( nom_ib ))
 		return;
 
-	    if ( stat ( nom_ib,
+	    if ( utf8_stat ( nom_ib,
 			&test_fichier ) != -1 )
 	    {
 		if ( S_ISREG ( test_fichier.st_mode ) )
@@ -2798,9 +2830,9 @@ void importer_ib ( void )
 
 
     fenetre_nom = gtk_file_selection_new (_("Import the budgetary lines" ));
-    gtk_file_selection_set_filename ( GTK_FILE_SELECTION ( fenetre_nom ),
+    file_selection_set_filename ( GTK_FILE_SELECTION ( fenetre_nom ),
 				      dernier_chemin_de_travail );
-    gtk_entry_set_text ( GTK_ENTRY ( GTK_FILE_SELECTION ( fenetre_nom )->selection_entry),
+    file_selection_set_entry ( GTK_FILE_SELECTION ( fenetre_nom ),
 			 ".igsb" );
 
     resultat = gtk_dialog_run ( GTK_DIALOG ( fenetre_nom ));
@@ -2811,7 +2843,7 @@ void importer_ib ( void )
 	return;
     }
 
-    nom_ib =g_strdup (gtk_file_selection_get_filename ( GTK_FILE_SELECTION ( fenetre_nom )));
+    nom_ib = file_selection_get_filename ( GTK_FILE_SELECTION ( fenetre_nom ));
 
     gtk_widget_destroy ( GTK_WIDGET ( fenetre_nom ));
 
