@@ -5,7 +5,12 @@
 #include <libintl.h>
 #include <locale.h>
 #include <stdio.h>
-#include <string.h>
+#ifdef HAVE_STRINGS_H
+#  include <strings.h>
+#endif
+#ifdef HAVE_STRING_H
+#  include <string.h>
+#endif
 #include <sys/types.h>
 #include <sys/timeb.h>
 #include <time.h>
@@ -26,5 +31,4 @@
 #define G_BROKEN_FILENAMES 1
 #include <gtk/gtktext.h>
 #include <gdk/gdkkeysyms.h>
-#include <popt.h>
 
