@@ -388,6 +388,29 @@ void reaffiche_liste_comptes ( void )
 			       FALSE );
 
 
+    /* on efface dans le menu dition la liste des comptes vers lesquels on peut
+       dplacer les oprations */
+
+    p_tab_nom_de_compte_variable = p_tab_nom_de_compte;
+
+    for ( i=0 ; i<nb_comptes ; i++ )
+    {
+	gchar *tmp;
+
+	tmp = my_strdelimit ( NOM_DU_COMPTE,
+			      "/",
+			      "\\/" );
+
+	gtk_item_factory_delete_item ( item_factory_menu_general,
+				       menu_name(_("Edit"), _("Move transaction to another account"), tmp ));
+	p_tab_nom_de_compte_variable++;
+    }
+
+    gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
+							   menu_name(_("Edit"), _("Move transaction to another account"), NULL)),
+			       FALSE );
+
+
     /*  Cration d'une icone et du nom par compte, et placement dans la liste selon l'ordre dsir  */
 
     ordre_comptes_variable = ordre_comptes;
@@ -443,6 +466,55 @@ void reaffiche_liste_comptes ( void )
     }
     while ( (  ordre_comptes_variable = ordre_comptes_variable->next ) );
 
+
+    /* Cration dans le menu dition de la liste des comptes vers lesquels on
+       peut dplacer les oprations */
+
+    ordre_comptes_variable = ordre_comptes;
+    do
+    {
+	p_tab_nom_de_compte_variable = p_tab_nom_de_compte + GPOINTER_TO_INT ( ordre_comptes_variable->data );
+
+	if ( ! COMPTE_CLOTURE )
+	{
+	    GtkItemFactoryEntry *item_factory_entry;
+	    gchar *tmp;
+
+
+	    item_factory_entry = calloc ( 1, sizeof ( GtkItemFactoryEntry ));
+
+	    tmp = my_strdelimit ( NOM_DU_COMPTE, "/", "\\/" );
+	    ;
+
+	    item_factory_entry -> path = menu_name(_("Edit"), 
+						   _("Move transaction to another account"), 
+						   my_strdelimit ( tmp, "_", "__" ) ); 
+
+	    item_factory_entry -> callback = G_CALLBACK ( move_selected_operation_to_account_nb );
+
+	    /* 	    on rajoute 1 car sinon pour le compte 0 a passerait pas... */
+
+	    item_factory_entry -> callback_action = GPOINTER_TO_INT ( ordre_comptes_variable->data ) + 1;
+
+	    gtk_item_factory_create_item ( item_factory_menu_general,
+					   item_factory_entry,
+					   ordre_comptes_variable -> data,
+					   1 );
+
+	    gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
+								   menu_name(_("Edit"), _("Move transaction to another account"), NULL)),
+				       TRUE );
+
+	    /* si c'est le compte courant, on grise l'entre menu */
+
+	    if ( p_tab_nom_de_compte_variable == p_tab_nom_de_compte + compte_courant )
+	    gtk_widget_set_sensitive ( gtk_item_factory_get_item ( item_factory_menu_general,
+								   menu_name(_("Edit"), _("Move transaction to another account"), tmp)),
+				       FALSE );
+	}
+    }
+    while ( (  ordre_comptes_variable = ordre_comptes_variable->next ) );
+
 }
 /* *********************************************************************************************************** */
 
