@@ -31,6 +31,7 @@
 #include "dialog.h"
 #include "search_glist.h"
 #include "utils.h"
+#include "utils_files.h"
 
 
 
@@ -46,6 +47,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
     GSList *liste_tmp;
     gchar **tab;
     gint pas_le_premier_compte = 0;
+    gchar *type;
 
     /* fichier pointe sur le fichier qui a t reconnu comme qif */
 
@@ -69,6 +71,8 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 	    else
 		pas_le_premier_compte = 2;
 
+	    type = NULL;
+
 	    if ( retour
 		 &&
 		 retour != EOF
@@ -82,30 +86,36 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 		/* 	     ce niveau on est sur un !type ou !Type, on vrifie maintenant qu'on supporte */
 		/* 		bien ce type ; si c'est le cas, on met retour  -1 */
 
-		if ( !my_strncasecmp ( pointeur_char+6,
-				       "bank",
-				       4 )
+		tab = g_strsplit ( pointeur_char,
+				   ":",
+				   2 );
+
+		if ( tab[1] )
+		    tab[1] = g_strstrip ( tab[1] );
+
+		if ( !my_strcasecmp ( tab[1],
+				      "bank" )
 		     ||
-		     !my_strncasecmp ( pointeur_char+6,
-				       "cash",
-				       4 )
+		     !my_strcasecmp ( tab[1],
+				      "cash" )
 		     ||
-		     !my_strncasecmp ( pointeur_char+6,
-				       "ccard",
-				       5 )
+		     !my_strcasecmp ( tab[1],
+				      "ccard" )
 		     ||
-		     !my_strncasecmp ( pointeur_char+6,
-				       "invst",
-				       5 )
+		     !my_strcasecmp ( tab[1],
+				      "invst" )
 		     ||
-		     !my_strncasecmp ( pointeur_char+6,
-				       "oth a",
-				       5 )
+		     !my_strcasecmp ( tab[1],
+				      "oth a" )
 		     ||
-		     !my_strncasecmp ( pointeur_char+6,
-				       "oth l",
-				       5 ))
-					   retour = -2;
+		     !my_strcasecmp ( tab[1],
+				      "oth l" ))
+		{
+		    retour = -2;
+		    type = g_strdup ( tab[1] );
+		}
+
+		g_strfreev ( tab );
 	    }
 	}
 	while ( retour != EOF
@@ -126,6 +136,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 	}
 
 	/*     on est sur le dbut d'oprations d'un compte, on cre un nouveau compte */
+	/* 	si on est ici, la variable type contient le type de compte */
 
 	compte = calloc ( 1,
 			  sizeof ( struct struct_compte_importation ));
@@ -136,15 +147,13 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 
 	/* rcupration du type de compte */
 
-	if ( !my_strncasecmp ( pointeur_char+6,
-			       "bank",
-			       4 ))
+	if ( !my_strcasecmp ( type,
+			      "bank" ))
 	    compte -> type_de_compte = 0;
 	else
 	{
-	    if ( !my_strncasecmp ( pointeur_char+6,
-				   "invst",
-				   5 ))
+	    if ( !my_strcasecmp ( type,
+				  "invst" ))
 	    {
 /* 		on considre le compte d'investissement comme un compte bancaire mais met un */
 /* 		    warning car pas implment ; aucune ide si a passe ou pas... */
@@ -153,21 +162,18 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 	    }
 	    else
 	    {
-		if ( !my_strncasecmp ( pointeur_char+6,
-				       "cash",
-				       4 ))
+		if ( !my_strcasecmp ( type,
+				      "cash" ))
 		    compte -> type_de_compte = 7;
 		else
 		{
-		    if ( !my_strncasecmp ( pointeur_char+6,
-					   "oth a",
-					   5 ))
+		    if ( !my_strcasecmp ( type,
+					  "oth a" ))
 			compte -> type_de_compte = 2;
 		    else
 		    {
-			if ( !my_strncasecmp ( pointeur_char+6,
-					       "oth l",
-					       5 ))
+			if ( !my_strcasecmp ( type,
+					      "oth l" ))
 			    compte -> type_de_compte = 3;
 			else
 			    /* CCard */
@@ -176,7 +182,7 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 		}
 	    }
 	}
-    
+
 
 
 	/* rcupre les autres donnes du compte */
@@ -185,9 +191,8 @@ gboolean recuperation_donnees_qif ( FILE *fichier )
 	/* 	caractristiques de dpart du compte, on cre donc un compte du nom */
 	/* "carte de crdit" avec un solde init de 0 */
 
-	if ( my_strncasecmp ( pointeur_char+6,
-			      "ccard",
-			      5 ))
+	if ( my_strcasecmp ( type,
+			      "ccard" ))
 	{
 	    /* ce n'est pas une ccard, on rcupre les infos */
 
@@ -633,7 +638,7 @@ changement_format_date:
 					   NULL );
 		    }
 
-		    if ( strlen ( tab_str[2] ) == 4 )
+		    if ( strlen ( tab_str[2] ) >= 4 )
 			annee = my_strtod ( tab_str[2],
 					    NULL );
 		    else
@@ -696,7 +701,7 @@ changement_format_date:
 					   NULL );
 			jour = my_strtod ( tab_str[2],
 					   NULL );
-			if ( strlen ( tab_str[0] ) == 4 )
+			if ( strlen ( tab_str[0] ) >= 4 )
 			    annee = my_strtod ( tab_str[0],
 						NULL );
 			else
@@ -1003,7 +1008,7 @@ choix_liste_fichier:
 	nom_fichier_qif = g_strdup ( gtk_entry_get_text ( GTK_ENTRY ( liste_tmp -> data )));
 
 
-	if ( stat ( nom_fichier_qif, &test_fichier ) != -1 )
+	if ( utf8_stat ( nom_fichier_qif, &test_fichier ) != -1 )
 	{
 	    if ( S_ISREG ( test_fichier.st_mode ) )
 	    {
@@ -1038,7 +1043,7 @@ choix_liste_fichier:
 
 	nom_fichier_qif = g_strdup ( gtk_entry_get_text ( GTK_ENTRY ( liste_tmp -> data )));
 
-	if ( !( fichier_qif = fopen ( nom_fichier_qif,
+	if ( !( fichier_qif = utf8_fopen ( nom_fichier_qif,
 				      "w" ) ))
 	    dialogue ( g_strdup_printf ( _("Error for the file \"%s\" :\n%s"),
 					 nom_fichier_qif, strerror ( errno ) ));
@@ -1480,3 +1485,431 @@ void click_compte_export_qif ( GtkWidget *bouton,
 }
 /* *******************************************************************************/
 
+
+void export_qif (GSList* export_entries_list )
+{
+    gchar *nom_fichier_qif, *montant_tmp;
+    GSList *liste_tmp;
+    FILE *fichier_qif;
+
+    liste_tmp = export_entries_list;
+
+    while ( liste_tmp )
+    {
+
+	/*       ouverture du fichier, si pb, on marque l'erreur et passe au fichier suivant */
+
+	nom_fichier_qif = g_strdup ( gtk_entry_get_text ( GTK_ENTRY ( liste_tmp -> data )));
+
+	if ( !( fichier_qif = utf8_fopen ( nom_fichier_qif,
+				      "w" ) ))
+	    dialogue ( g_strdup_printf ( _("Error for the file \"%s\" :\n%s"),
+					 nom_fichier_qif, strerror ( errno ) ));
+	else
+	{
+	    GSList *pointeur_tmp;
+	    struct structure_operation *operation;
+
+	    p_tab_nom_de_compte_variable = 
+		p_tab_nom_de_compte
+		+
+		GPOINTER_TO_INT ( gtk_object_get_data ( GTK_OBJECT ( liste_tmp -> data ),
+							"no_compte" ));
+
+	    /* met le type de compte */
+
+	    if ( TYPE_DE_COMPTE == 1 )
+		fprintf ( fichier_qif,
+			  "!Type:Cash\n" );
+	    else
+		if ( TYPE_DE_COMPTE == 2
+		     ||
+		     TYPE_DE_COMPTE == 3 )
+		    fprintf ( fichier_qif,
+			      "!Type:Oth L\n" );
+		else
+		    fprintf ( fichier_qif,
+			      "!Type:Bank\n" );
+
+
+	    if ( LISTE_OPERATIONS )
+	    {
+		/* met la date de la 1re opration comme dte d'ouverture de compte */
+
+		operation = LISTE_OPERATIONS -> data;
+
+		fprintf ( fichier_qif,
+			  "D%d/%d/%d\n",
+			  operation -> jour,
+			  operation -> mois,
+			  operation -> annee );
+
+
+
+		/* met le solde initial */
+
+		montant_tmp = g_strdup_printf ( "%4.2f",
+						SOLDE_INIT );
+		montant_tmp = g_strdelimit ( montant_tmp,
+					     ",",
+					     '.' );
+
+		fprintf ( fichier_qif,
+			  "T%s\n",
+			  montant_tmp );
+
+
+		fprintf ( fichier_qif,
+			  "CX\nPOpening Balance\n" );
+
+		/* met le nom du compte */
+
+		fprintf ( fichier_qif,
+			  "L%s\n^\n",
+			  g_strconcat ( "[",
+					NOM_DU_COMPTE,
+					"]",
+					NULL ) );
+
+		/* on met toutes les oprations */
+
+		pointeur_tmp = LISTE_OPERATIONS;
+
+		while ( pointeur_tmp )
+		{
+		    GSList *pointeur;
+		    gdouble montant;
+		    struct struct_type_ope *type;
+
+		    operation = pointeur_tmp -> data;
+
+
+		    /* si c'est une op de ventilation, on la saute pas elle sera recherche quand */
+		    /* son op ventile sera exporte */
+
+		    if ( !operation -> no_operation_ventilee_associee )
+		    {
+			/* met la date */
+
+			fprintf ( fichier_qif,
+				  "D%d/%d/%d\n",
+				  operation -> jour,
+				  operation -> mois,
+				  operation -> annee );
+
+
+			/* met le pointage */
+
+			if ( operation -> pointe == 1
+			     ||
+			     operation -> pointe == 3 )
+			    fprintf ( fichier_qif,
+				      "C*\n" );
+			else
+			    if ( operation -> pointe == 2 )
+				fprintf ( fichier_qif,
+					  "CX\n" );
+
+
+			/* met les notes */
+
+			if ( operation -> notes )
+			    fprintf ( fichier_qif,
+				      "M%s\n",
+				      operation -> notes );
+
+
+			/* met le montant, transforme la devise si necessaire */
+
+			montant = calcule_montant_devise_renvoi ( operation -> montant,
+								  DEVISE,
+								  operation -> devise,
+								  operation -> une_devise_compte_egale_x_devise_ope,
+								  operation -> taux_change,
+								  operation -> frais_change );
+
+			montant_tmp = g_strdup_printf ( "%4.2f",
+							montant );
+			montant_tmp = g_strdelimit ( montant_tmp,
+						     ",",
+						     '.' );
+
+			fprintf ( fichier_qif,
+				  "T%s\n",
+				  montant_tmp );
+
+
+			/* met le chque si c'est un type  numrotation automatique */
+
+			pointeur = g_slist_find_custom ( TYPES_OPES,
+							 GINT_TO_POINTER ( operation -> type_ope ),
+							 (GCompareFunc) recherche_type_ope_par_no );
+
+			if ( pointeur )
+			{
+			    type = pointeur -> data;
+
+			    if ( type -> numerotation_auto )
+				fprintf ( fichier_qif,
+					  "N%s\n",
+					  operation -> contenu_type );
+			}
+
+			/* met le tiers */
+
+			pointeur = g_slist_find_custom ( liste_struct_tiers,
+							 GINT_TO_POINTER ( operation -> tiers ),
+							 (GCompareFunc) recherche_tiers_par_no );
+
+			if ( pointeur )
+			    fprintf ( fichier_qif,
+				      "P%s\n",
+				      ((struct struct_tiers *)(pointeur -> data )) -> nom_tiers );
+
+
+
+			/*  on met soit un virement, soit une ventilation, soit les catgories */
+
+			/* si c'est une ventilation, on recherche toutes les ops de cette ventilation */
+			/* et les met  la suite */
+			/* la catgorie de l'op sera celle de la premire op de ventilation */
+
+			if ( operation -> operation_ventilee )
+			{
+			    GSList *liste_ventil;
+			    gint categ_ope_mise;
+
+			    categ_ope_mise = 0;
+			    liste_ventil = LISTE_OPERATIONS;
+
+			    while ( liste_ventil )
+			    {
+				struct structure_operation *ope_test;
+
+				ope_test = liste_ventil -> data;
+
+				if ( ope_test -> no_operation_ventilee_associee == operation -> no_operation
+				     &&
+				     ( ope_test -> categorie
+				       ||
+				       ope_test -> relation_no_operation ))
+				{
+				    /* on commence par mettre la catg et sous categ de l'op et de l'op de ventilation */
+
+				    if ( ope_test -> relation_no_operation )
+				    {
+					/* c'est un virement */
+
+					gpointer **save_ptab;
+
+					save_ptab = p_tab_nom_de_compte_variable;
+
+					p_tab_nom_de_compte_variable = p_tab_nom_de_compte + ope_test -> relation_no_compte;
+
+					if ( !categ_ope_mise )
+					{
+					    fprintf ( fichier_qif,
+						      "L%s\n",
+						      g_strconcat ( "[",
+								    NOM_DU_COMPTE,
+								    "]",
+								    NULL ));
+					    categ_ope_mise = 1;
+					}
+
+					fprintf ( fichier_qif,
+						  "S%s\n",
+						  g_strconcat ( "[",
+								NOM_DU_COMPTE,
+								"]",
+								NULL ));
+
+					p_tab_nom_de_compte_variable = save_ptab;
+				    }
+				    else
+				    {
+					/* c'est du type categ : sous categ */
+
+					pointeur = g_slist_find_custom ( liste_struct_categories,
+									 GINT_TO_POINTER ( ope_test -> categorie ),
+									 (GCompareFunc) recherche_categorie_par_no );
+
+					if ( pointeur )
+					{
+					    GSList *pointeur_2;
+					    struct struct_categ *categorie;
+
+					    categorie = pointeur -> data;
+
+					    pointeur_2 = g_slist_find_custom ( categorie -> liste_sous_categ,
+									       GINT_TO_POINTER ( ope_test -> sous_categorie ),
+									       (GCompareFunc) recherche_sous_categorie_par_no );
+					    if ( pointeur_2 )
+					    {
+						if ( !categ_ope_mise )
+						{
+						    fprintf ( fichier_qif,
+							      "L%s\n",
+							      g_strconcat ( categorie -> nom_categ,
+									    ":",
+									    ((struct struct_sous_categ *)(pointeur_2->data)) -> nom_sous_categ,
+									    NULL ));
+						    categ_ope_mise = 1;
+						}
+
+						fprintf ( fichier_qif,
+							  "S%s\n",
+							  g_strconcat ( categorie -> nom_categ,
+									":",
+									((struct struct_sous_categ *)(pointeur_2->data)) -> nom_sous_categ,
+									NULL ));
+					    }
+					    else
+					    {
+						if ( !categ_ope_mise )
+						{
+						    fprintf ( fichier_qif,
+							      "L%s\n",
+							      categorie -> nom_categ );
+						    categ_ope_mise = 1;
+						}
+
+						fprintf ( fichier_qif,
+							  "S%s\n",
+							  categorie -> nom_categ );
+					    }
+					}
+				    }
+
+
+				    /* met les notes de la ventilation */
+
+				    if ( ope_test -> notes )
+					fprintf ( fichier_qif,
+						  "E%s\n",
+						  ope_test -> notes );
+
+				    /* met le montant de la ventilation */
+
+				    montant = calcule_montant_devise_renvoi ( ope_test -> montant,
+									      DEVISE,
+									      operation -> devise,
+									      operation -> une_devise_compte_egale_x_devise_ope,
+									      operation -> taux_change,
+									      operation -> frais_change );
+
+				    montant_tmp = g_strdup_printf ( "%4.2f",
+								    montant );
+				    montant_tmp = g_strdelimit ( montant_tmp,
+								 ",",
+								 '.' );
+
+				    fprintf ( fichier_qif,
+					      "$%s\n",
+					      montant_tmp );
+
+				}
+
+				liste_ventil = liste_ventil -> next;
+			    }
+			}
+			else
+			{
+			    /* si c'est un virement vers un compte supprim, a sera pris comme categ normale vide */
+
+			    if ( operation -> relation_no_operation
+				 &&
+				 operation -> relation_no_compte >= 0 )
+			    {
+				/* c'est un virement */
+
+				gpointer **save_ptab;
+
+				save_ptab = p_tab_nom_de_compte_variable;
+
+				p_tab_nom_de_compte_variable = p_tab_nom_de_compte + operation -> relation_no_compte;
+
+				fprintf ( fichier_qif,
+					  "L%s\n",
+					  g_strconcat ( "[",
+							NOM_DU_COMPTE,
+							"]",
+							NULL ));
+
+				p_tab_nom_de_compte_variable = save_ptab;
+			    }
+			    else
+			    {
+				/* c'est du type categ : sous-categ */
+
+				pointeur = g_slist_find_custom ( liste_struct_categories,
+								 GINT_TO_POINTER ( operation -> categorie ),
+								 (GCompareFunc) recherche_categorie_par_no );
+
+				if ( pointeur )
+				{
+				    GSList *pointeur_2;
+				    struct struct_categ *categorie;
+
+				    categorie = pointeur -> data;
+
+				    pointeur_2 = g_slist_find_custom ( categorie -> liste_sous_categ,
+								       GINT_TO_POINTER ( operation -> sous_categorie ),
+								       (GCompareFunc) recherche_sous_categorie_par_no );
+				    if ( pointeur_2 )
+					fprintf ( fichier_qif,
+						  "L%s\n",
+						  g_strconcat ( categorie -> nom_categ,
+								":",
+								((struct struct_sous_categ *)(pointeur_2->data)) -> nom_sous_categ,
+								NULL ));
+				    else
+					fprintf ( fichier_qif,
+						  "L%s\n",
+						  categorie -> nom_categ );
+				}
+			    }
+			}
+
+			fprintf ( fichier_qif,
+				  "^\n" );
+		    }
+
+		    pointeur_tmp = pointeur_tmp -> next;
+		}
+	    }
+	    else
+	    {
+		/* le compte n'a aucune opration enregistre : on ne met pas de date, mais on fait l'ouverture du compte */
+
+		/* met le solde initial */
+
+		montant_tmp = g_strdup_printf ( "%4.2f",
+						SOLDE_INIT );
+		montant_tmp = g_strdelimit ( montant_tmp,
+					     ",",
+					     '.' );
+
+		fprintf ( fichier_qif,
+			  "T%s\n",
+			  montant_tmp );
+
+
+		fprintf ( fichier_qif,
+			  "CX\nPOpening Balance\n" );
+
+		/* met le nom du compte */
+
+		fprintf ( fichier_qif,
+			  "L%s\n^\n",
+			  g_strconcat ( "[",
+					NOM_DU_COMPTE,
+					"]",
+					NULL ) );
+	    }
+	    fclose ( fichier_qif );
+	}
+	liste_tmp = liste_tmp -> next;
+    }
+
+}
