@@ -41,7 +41,6 @@
 #include "search_glist.h"
 #include "traitement_variables.h"
 #include "utils.h"
-#include "devises.h"
 
 
 #include "xpm/book-closed.xpm"
@@ -72,6 +71,7 @@ GtkWidget *onglet_tiers ( void )
     GtkWidget *frame;
     GtkWidget *vbox_frame;
     GtkWidget *hbox;
+    GtkWidget *scrolled_window_text;
 
     /* cration des pixmaps pour la liste */
     pixmap_ouvre = gdk_pixmap_create_from_xpm_d ( GTK_WIDGET(window) -> window,
@@ -145,21 +145,27 @@ GtkWidget *onglet_tiers ( void )
 			 0 );
     gtk_widget_show ( entree_nom_tiers );
 
+    scrolled_window_text = gtk_scrolled_window_new ( FALSE, FALSE );
+    gtk_scrolled_window_set_policy ( GTK_SCROLLED_WINDOW ( scrolled_window_text ),
+				     GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC );
+    gtk_scrolled_window_set_shadow_type ( GTK_SCROLLED_WINDOW(scrolled_window_text), 
+					  GTK_SHADOW_IN );
+    gtk_box_pack_start ( GTK_BOX ( vbox_frame ), scrolled_window_text, FALSE, FALSE, 0 );
 
-    text_box = gtk_text_new ( NULL,
-			      NULL );
-    gtk_widget_set_sensitive ( text_box,
-			       FALSE );
-    gtk_signal_connect ( GTK_OBJECT ( text_box ),
-			 "changed",
-			 GTK_SIGNAL_FUNC ( modification_du_texte_tiers),
-			 NULL );
-    gtk_box_pack_start ( GTK_BOX ( vbox_frame ),
-			 text_box,
-			 FALSE,
-			 FALSE,
-			 0 );
-    gtk_widget_show ( text_box );
+    text_box = gtk_text_view_new ();
+    gtk_text_view_set_pixels_above_lines (GTK_TEXT_VIEW (text_box), 3);
+    gtk_text_view_set_pixels_below_lines (GTK_TEXT_VIEW (text_box), 3);
+    gtk_text_view_set_left_margin (GTK_TEXT_VIEW (text_box), 3);
+    gtk_text_view_set_right_margin (GTK_TEXT_VIEW (text_box), 3);
+    gtk_text_view_set_wrap_mode ( GTK_TEXT_VIEW (text_box), GTK_WRAP_WORD );
+    gtk_container_add ( GTK_CONTAINER(scrolled_window_text), text_box );
+
+    gtk_widget_set_sensitive ( text_box, FALSE );
+
+    g_signal_connect ( G_OBJECT(gtk_text_view_get_buffer(GTK_TEXT_VIEW(text_box))),
+		       "changed", ((GCallback) modification_du_texte_tiers), NULL );
+
+    gtk_widget_show_all ( scrolled_window_text );
 
     /*   cration des boutons modifier et annuler */
 
@@ -778,20 +784,18 @@ gboolean selection_ligne_tiers ( GtkCTree *arbre_tiers, GtkCTreeNode *noeud,
 						  GTK_CTREE_ROW ( GTK_CTREE_ROW ( noeud ) -> parent ) -> parent );
 
 
-    gtk_signal_handler_block_by_func ( GTK_OBJECT ( text_box ),
-				       GTK_SIGNAL_FUNC ( modification_du_texte_tiers),
-				       NULL );
+    g_signal_handlers_block_by_func ( G_OBJECT ( gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_box)) ),
+				      GTK_SIGNAL_FUNC ( modification_du_texte_tiers),
+				      NULL );
     gtk_signal_handler_block_by_func ( GTK_OBJECT ( entree_nom_tiers ),
 				       GTK_SIGNAL_FUNC ( modification_du_texte_tiers),
 				       NULL );
 
     if ( tiers -> texte )
-	gtk_text_insert ( GTK_TEXT ( text_box ),
-			  NULL,
-			  NULL,
-			  NULL,
-			  tiers->texte,
-			  -1 );
+      {
+	gtk_text_buffer_set_text ( gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_box)),
+				   ( tiers->texte ? tiers->texte : "") , -1 );
+      }
 
     gtk_entry_set_text ( GTK_ENTRY ( entree_nom_tiers ),
 			 tiers -> nom_tiers );
@@ -799,17 +803,17 @@ gboolean selection_ligne_tiers ( GtkCTree *arbre_tiers, GtkCTreeNode *noeud,
     gtk_signal_handler_unblock_by_func ( GTK_OBJECT ( entree_nom_tiers ),
 					 GTK_SIGNAL_FUNC ( modification_du_texte_tiers),
 					 NULL );
-    gtk_signal_handler_unblock_by_func ( GTK_OBJECT ( text_box ),
-					 GTK_SIGNAL_FUNC ( modification_du_texte_tiers),
-					 NULL );
+    g_signal_handlers_unblock_by_func ( G_OBJECT ( gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_box)) ),
+					GTK_SIGNAL_FUNC ( modification_du_texte_tiers),
+					NULL );
 
 
-    if ( tiers -> liaison )
-	gtk_text_set_editable ( GTK_TEXT ( text_box ),
-				FALSE );
-    else
-	gtk_text_set_editable ( GTK_TEXT ( text_box ),
-				TRUE );
+/*     if ( tiers -> liaison ) */
+/* 	gtk_text_set_editable ( GTK_TEXT ( text_box ), */
+/* 				FALSE ); */
+/*     else */
+/* 	gtk_text_set_editable ( GTK_TEXT ( text_box ), */
+/* 				TRUE ); */
 
 
     gtk_object_set_data ( GTK_OBJECT ( text_box ),
@@ -902,32 +906,29 @@ gboolean enleve_selection_ligne_tiers ( void )
 			       FALSE );
 
 
-    gtk_signal_handler_block_by_func ( GTK_OBJECT ( text_box ),
-				       GTK_SIGNAL_FUNC ( modification_du_texte_tiers),
-				       NULL );
+    g_signal_handlers_block_by_func ( G_OBJECT ( gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_box)) ),
+				      GTK_SIGNAL_FUNC ( modification_du_texte_tiers),
+				      NULL );
     gtk_signal_handler_block_by_func ( GTK_OBJECT ( entree_nom_tiers ),
 				       GTK_SIGNAL_FUNC ( modification_du_texte_tiers),
 				       NULL );
 
-    gtk_editable_delete_text ( GTK_EDITABLE ( entree_nom_tiers ),
-			       0,
-			       -1 );
-    gtk_editable_delete_text ( GTK_EDITABLE ( text_box ),
-			       0,
-			       -1 );
+    gtk_editable_delete_text ( GTK_EDITABLE ( entree_nom_tiers ), 0, -1 );
+    gtk_text_buffer_set_text ( gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_box)),
+			       "", -1 );
 
     gtk_signal_handler_unblock_by_func ( GTK_OBJECT ( entree_nom_tiers ),
 					 GTK_SIGNAL_FUNC ( modification_du_texte_tiers),
 					 NULL );
-    gtk_signal_handler_unblock_by_func ( GTK_OBJECT ( text_box ),
-					 GTK_SIGNAL_FUNC ( modification_du_texte_tiers),
-					 NULL );
+    g_signal_handlers_unblock_by_func ( G_OBJECT ( gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_box)) ),
+					GTK_SIGNAL_FUNC ( modification_du_texte_tiers),
+					NULL );
 
     gtk_object_remove_data ( GTK_OBJECT (  text_box ),
 			     "adr_struct_tiers" );
 
-    gtk_editable_set_editable ( GTK_EDITABLE ( text_box ),
-				FALSE );
+/*     gtk_editable_set_editable ( GTK_EDITABLE ( text_box ), */
+/* 				FALSE ); */
 
     return FALSE;
 }
@@ -1006,11 +1007,15 @@ void clique_sur_modifier_tiers ( GtkWidget *bouton_modifier,
     }
     else
     {
+        GtkTextIter start, end;
+	GtkTextBuffer *buffer;
+
 	free ( tiers -> texte );
 
-	tiers -> texte = g_strstrip ( gtk_editable_get_chars (GTK_EDITABLE ( text_box ),
-							      0,
-							      gtk_text_get_length (GTK_TEXT (text_box))) );
+        buffer = gtk_text_view_get_buffer ( GTK_TEXT_VIEW ( text_box ) );
+	gtk_text_buffer_get_iter_at_offset ( buffer, &start, 0 );
+	gtk_text_buffer_get_iter_at_offset ( buffer, &end, -1 );
+	tiers -> texte = gtk_text_buffer_get_text ( buffer , &start, &end, TRUE );
     }
 
     gtk_widget_set_sensitive ( bouton_modif_tiers_modifier,
@@ -1033,28 +1038,18 @@ void clique_sur_annuler_tiers ( GtkWidget *bouton_annuler,
     tiers =  gtk_object_get_data ( GTK_OBJECT (  text_box ),
 				   "adr_struct_tiers" );
 
-    gtk_editable_delete_text ( GTK_EDITABLE ( text_box ),
-			       0,
-			       -1 );
-
-    if ( tiers -> texte )
-	gtk_text_insert ( GTK_TEXT ( text_box ),
-			  NULL,
-			  NULL,
-			  NULL,
-			  tiers->texte,
-			  -1 );
-
+    gtk_text_buffer_set_text ( gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_box)),
+			       (tiers->texte ? tiers->texte : ""), -1 );
 
     gtk_entry_set_text ( GTK_ENTRY ( entree_nom_tiers ),
 			 tiers -> nom_tiers );
 
-    if ( tiers -> liaison )
-	gtk_text_set_editable ( GTK_TEXT ( text_box ),
-				FALSE );
-    else
-	gtk_text_set_editable ( GTK_TEXT ( text_box ),
-				TRUE );
+/*     if ( tiers -> liaison ) */
+/* 	gtk_text_set_editable ( GTK_TEXT ( text_box ), */
+/* 				FALSE ); */
+/*     else */
+/* 	gtk_text_set_editable ( GTK_TEXT ( text_box ), */
+/* 				TRUE ); */
 
     gtk_widget_set_sensitive ( bouton_modif_tiers_modifier,
 			       FALSE );
@@ -1179,7 +1174,7 @@ void supprimer_tiers ( GtkWidget *bouton,
 	GtkWidget *bouton_tiers_generique;
 	GtkWidget *combofix;
 	GSList *liste_combofix;
-	GSList *pointeur;
+	GSList *pointeur, *tmp;
 	GtkWidget *bouton_transfert;
 	gint i;
 	gint nouveau_no;
@@ -1224,7 +1219,6 @@ void supprimer_tiers ( GtkWidget *bouton,
 			     FALSE,
 			     0 );
 
-
 	pointeur = liste_struct_tiers;
 	liste_combofix = NULL;
 
@@ -1236,12 +1230,12 @@ void supprimer_tiers ( GtkWidget *bouton,
 	    pointeur = pointeur -> next;
 	}
 
-
 	combofix = gtk_combofix_new ( liste_combofix,
+				      FALSE,
 				      TRUE,
 				      TRUE,
-				      TRUE,
-				      50 );
+				      0 );
+
 	gtk_box_pack_start ( GTK_BOX ( hbox ),
 			     combofix,
 			     FALSE,
@@ -1293,9 +1287,19 @@ retour_dialogue:
 
 	    /* recherche du nouveau numro de tiers */
 
-	    nouveau_tiers = g_slist_find_custom ( liste_struct_tiers,
-						  gtk_combofix_get_text ( GTK_COMBOFIX ( combofix ) ),
-						  (GCompareFunc) recherche_tiers_par_nom ) -> data;
+	    tmp = g_slist_find_custom ( liste_struct_tiers,
+					gtk_combofix_get_text ( GTK_COMBOFIX ( combofix ) ),
+					(GCompareFunc) recherche_tiers_par_nom );
+	    if ( !tmp || ! tmp -> data )
+	    {
+		dialogue_error_hint ( _("Grisbi is unable to find this third party.  Be sure entered name is valid and that this third party exists."),
+				      g_strdup_printf ( _("Third party %s not found."),
+							gtk_combofix_get_text ( GTK_COMBOFIX ( combofix ) ) ) );
+		goto retour_dialogue;
+	
+	    }
+
+	    nouveau_tiers = tmp -> data;
 	    nouveau_no = nouveau_tiers -> no_tiers;
 	}
 	else
@@ -1361,8 +1365,8 @@ retour_dialogue:
     mise_a_jour_tiers ();
     remplit_arbre_tiers ();
 
-    gtk_text_set_editable ( GTK_TEXT ( text_box ),
-			    FALSE );
+/*     gtk_text_set_editable ( GTK_TEXT ( text_box ), */
+/* 			    FALSE ); */
 
     modification_fichier(TRUE);
 }
@@ -1645,6 +1649,16 @@ void appui_sur_ajout_tiers ( void )
     if ( !nom_tiers || !strcmp(nom_tiers, ""))
 	return;
 
+    if ( g_slist_find_custom ( liste_struct_tiers,
+			       nom_tiers,
+			       (GCompareFunc) recherche_tiers_par_nom ) )
+      {
+	dialogue_warning_hint ( _("Third party names must be both unique and not empty.  Please use another name for this third party."),
+				g_strdup_printf ( _("Third party '%s' already exists."),
+						  nom_tiers ) );
+	return;
+      }
+
     /* on l'ajoute  la liste des ops */
 
     nouveau_tiers = ajoute_nouveau_tiers ( nom_tiers );
