@@ -1,24 +1,25 @@
-/* Ce fichier s'occupe de la gestion des types d'oprations */
-/* type_operations.c */
-
-/*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org) */
-/*			2003 Benjamin Drieu (bdrieu@april.org) */
-/* 			http://www.grisbi.org */
-
-/*     This program is free software; you can redistribute it and/or modify */
-/*     it under the terms of the GNU General Public License as published by */
-/*     the Free Software Foundation; either version 2 of the License, or */
-/*     (at your option) any later version. */
-
-/*     This program is distributed in the hope that it will be useful, */
-/*     but WITHOUT ANY WARRANTY; without even the implied warranty of */
-/*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the */
-/*     GNU General Public License for more details. */
-
-/*     You should have received a copy of the GNU General Public License */
-/*     along with this program; if not, write to the Free Software */
-/*     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
-
+/* ************************************************************************** */
+/* Ce fichier s'occupe de la gestion des types d'oprations		      */
+/*                                                                            */
+/*     Copyright (C)	2000-2003 Cdric Auger (cedric@grisbi.org)	      */
+/*			2003-2004 Benjamin Drieu (bdrieu@april.org)	      */
+/* 			http://www.grisbi.org				      */
+/*                                                                            */
+/*  This program is free software; you can redistribute it and/or modify      */
+/*  it under the terms of the GNU General Public License as published by      */
+/*  the Free Software Foundation; either version 2 of the License, or         */
+/*  (at your option) any later version.                                       */
+/*                                                                            */
+/*  This program is distributed in the hope that it will be useful,           */
+/*  but WITHOUT ANY WARRANTY; without even the implied warranty of            */
+/*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
+/*  GNU General Public License for more details.                              */
+/*                                                                            */
+/*  You should have received a copy of the GNU General Public License         */
+/*  along with this program; if not, write to the Free Software               */
+/*  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/*                                                                            */
+/* ************************************************************************** */
 
 #include "include.h"
 #include "structures.h"
@@ -979,6 +980,9 @@ void supprimer_type_operation ( void )
 			     PAYMENT_METHODS_POINTER_COLUMN, &type_ope,
 			     -1 );
 
+	if ( ! type_ope )
+	    return;
+
 	/** We then put related operations in a temporary list */
 	p_tab_nom_de_compte_variable = p_tab_nom_de_compte + type_ope -> no_compte;
 	pointeur_tmp = LISTE_OPERATIONS;
@@ -1469,7 +1473,7 @@ gint cherche_no_menu_type ( gint demande )
 gint cherche_no_menu_type_associe ( gint demande,
 				    gint origine )
 {
-    GList *liste_tmp;
+    GList *liste_tmp = NULL;
     gint retour;
     gint i;
 
@@ -1477,9 +1481,17 @@ gint cherche_no_menu_type_associe ( gint demande,
 	return ( FALSE );
 
     if ( origine )
-	liste_tmp = GTK_MENU_SHELL ( GTK_OPTION_MENU ( widget_formulaire_ventilation[TRANSACTION_BREAKDOWN_FORM_CONTRA] ) -> menu ) -> children;
+    {
+	GtkWidget * menu = GTK_OPTION_MENU ( widget_formulaire_operations[TRANSACTION_BREAKDOWN_FORM_CONTRA] ) -> menu;
+	if ( menu )
+	    liste_tmp = GTK_MENU_SHELL ( menu ) -> children;
+    }
     else
-	liste_tmp = GTK_MENU_SHELL ( GTK_OPTION_MENU ( widget_formulaire_operations[TRANSACTION_FORM_CONTRA] ) -> menu ) -> children;
+    {
+	GtkWidget * menu = GTK_OPTION_MENU ( widget_formulaire_operations[TRANSACTION_FORM_CONTRA] ) -> menu;
+	if ( menu )
+	    liste_tmp = GTK_MENU_SHELL ( menu ) -> children;
+    }
 
     retour = -1;
     i=0;
@@ -1588,7 +1600,7 @@ void changement_choix_type_formulaire ( struct struct_type_ope *type )
 	{
 	    entree_prend_focus ( widget_formulaire_operations[TRANSACTION_FORM_CHEQUE] );
 	    gtk_entry_set_text ( GTK_ENTRY ( widget_formulaire_operations[TRANSACTION_FORM_CHEQUE] ),
-				 itoa ( type -> no_en_cours  + 1));
+				 automatic_numbering_get_new_number ( type ));
 	}
 	else
 	{
@@ -1630,4 +1642,24 @@ void changement_choix_type_echeancier ( struct struct_type_ope *type )
     else
 	gtk_widget_hide ( widget_formulaire_echeancier[SCHEDULER_FORM_CHEQUE] );
 }
-/* ************************************************************************************************************** */
+
+
+
+/**
+ * Get the max content number associated to a type structure,
+ * increment it and return it.  Handy to find the next number to fill
+ * in the cheque field of the transaction form.
+ *
+ * \param type	The type structure to compute.
+ *
+ * \return	A textual representation of the maximum.
+ */
+gchar * automatic_numbering_get_new_number ( struct struct_type_ope * type )
+{
+    if ( type )
+    {
+	return itoa ( type -> no_en_cours  + 1 );
+    }
+
+    return "1";
+}
