@@ -402,7 +402,7 @@ faire : */
     for ( p = nptr; p < nptr + strlen(nptr); p++ )
     {
 	/* si c'est un espace ou le signe +, on passe au caractre suivant */
-	if ( isspace(*p) || *p == '+' )
+	if ( g_ascii_isspace(*p) || *p == '+' )
 	    continue;
 
 	/* si c'est le signe -, on positionne invert  1 et on passe
@@ -419,7 +419,8 @@ faire : */
 	    char *m;
 	    /* aller  la fin de la chaine */
 	    for ( m = p+1; m <= nptr+strlen(nptr) &&
-		  (isdigit(*m) || isspace(*m)); m++)
+		    (isdigit(*m) || isspace(*m)); m++)
+	      ;
 		/* de la fin de la chaine au dernier caractre avant le point
 		   ou la virgule, faire : */
 		for ( --m; m > p; m-- )
@@ -1672,102 +1673,10 @@ gboolean set_double ( GtkWidget * spin, gdouble * dummy)
 
 
 
-/**
- * Make a GtkEntry that will contain a file name, a GtkButton that
- * will pop up a file selector, pack them in a GtkHbox and return it.
- *
- * \return A newly created GtkHbox.
- */
-GtkWidget * my_file_chooser ()
-{
-    GtkWidget * hbox, *entry, *button;
-
-    hbox = gtk_hbox_new ( FALSE, 6 );
-
-    entry = gtk_entry_new ( );
-    gtk_box_pack_start ( GTK_BOX(hbox), entry, TRUE, TRUE, 0 );
-    g_object_set_data ( G_OBJECT(hbox), "entry", entry );
-
-    button = gtk_button_new_with_label ( _("Browse") );
-    gtk_box_pack_start ( GTK_BOX(hbox), button, FALSE, FALSE, 0 );
-
-    g_signal_connect ( G_OBJECT(button), "clicked",
-		       (GCallback) browse_file, entry );
-
-    return hbox;
-}
 
 
 
 
-/**
- * Handler triggered by clicking on the button of a "print to file"
- * combo.  Pop ups a file selector.
- *
- * \param button GtkButton widget that triggered this handler.
- * \param data A pointer to a GtkEntry that will be filled with the
- *             result of the file selector.
- */
-void browse_file ( GtkButton *button, gpointer data )
-{
-    GtkWidget * file_selector;
-
-    file_selector = gtk_file_selection_new (_("Print to file"));
-    gtk_window_set_transient_for ( GTK_WINDOW ( file_selector ),
-				   GTK_WINDOW ( window ));
-    gtk_window_set_modal ( GTK_WINDOW ( file_selector ), TRUE );
-
-    /* Connect button click to entry change */
-    g_object_set_data ( G_OBJECT(GTK_FILE_SELECTION (file_selector)->ok_button),
-			"entry", file_selector );
-    g_signal_connect ( GTK_OBJECT (GTK_FILE_SELECTION (file_selector)->ok_button),
-		       "clicked", G_CALLBACK (change_print_to_file), data);
-
-    /* Ensure that the dialog box is destroyed when the user clicks a button. */
-    g_signal_connect_swapped ( GTK_OBJECT (GTK_FILE_SELECTION (file_selector)->ok_button),
-			       "clicked", G_CALLBACK (gtk_widget_destroy), 
-			       (gpointer) file_selector); 
-
-    g_signal_connect_swapped ( GTK_OBJECT (GTK_FILE_SELECTION (file_selector)->cancel_button),
-			       "clicked", G_CALLBACK (gtk_widget_destroy),
-			       (gpointer) file_selector); 
-
-    gtk_widget_show_all ( file_selector );
-}
-
-/**
- * return the absolute path of where the configuration file should be located
- * on Un*x based system return $HOME
- * on Windows based systems return APPDATA\Grisbi
- * 
- * \return the absolute path of the configuration file directory
- */
-gchar* my_get_grisbirc_dir(void)
-{
-#ifndef _WIN32
-    return (gchar *) g_get_home_dir();
-#else
-    return win32_get_grisbirc_folder_path();
-#endif
-}
-
-/**
- * return the absolute path of the default accounts files location
- * on Un*x based system return $HOME
- * on Windows based systems return "My Documents"
- * 
- * \return the absolute path of the configuration file directory
- */
-gchar* my_get_gsb_file_default_dir(void)
-{
-#ifndef _WIN32
-    return (gchar *) g_get_home_dir();
-#else
-    return win32_get_my_documents_folder_path();
-#endif
-}
-
-
 /* ******************************************************************************* */
 /* my_strcasecmp : compare 2 chaines case-insensitive que ce soit utf8 ou ascii */
 /* ******************************************************************************* */
@@ -1829,8 +1738,7 @@ gint my_strncasecmp ( gchar *chaine_1,
 					 longueur );
 	    new_2 = g_utf8_collate_key ( g_utf8_casefold (  chaine_2,longueur ),
 					 longueur );
-	    retour = strcmp ( new_1,
-			      new_2);
+	    retour = strcasecmp ( new_1, new_2);
 	    g_free ( new_1 );
 	    g_free ( new_2 );
 	    return ( retour );
@@ -1848,61 +1756,6 @@ gint my_strncasecmp ( gchar *chaine_1,
 
 
 /* ******************************************************************************* */
-/* fonction qui rcupre une ligne de charactre dans le pointeur de fichier donn en argument */
-/* elle alloue la mmoire ncessaire et place le pointeur en argument sur la mmoire alloue */
-/* renvoie 0 en cas de pb, eof en cas de fin de fichier, 1 sinon */
-/* ******************************************************************************* */
-gint get_line_from_file ( FILE *fichier,
-			  gchar **string )
-{
-    gchar c = 0;
-    gint i = 0;
-    gint j = 0;
-    gchar *pointeur_char = NULL;
-
-    if ( !fichier )
-	return 0;
-	    
-    /*     on commence par allouer une taille de 30 caractres, qu'on augment ensuite de 30 par 30 */
-
-    pointeur_char = (gchar*)realloc(pointeur_char,30*sizeof(gchar));
-
-    if ( !pointeur_char )
-    {
-	/* 	aie, pb de mmoire, on vire */
-	dialogue_error ( _("Memory allocation error" ));
-	return 0;
-    }
-
-    while ( ( c != '\n' ) && (c != '\r'))
-    {
-	c =(gchar)fgetc(fichier);
-	if (feof(fichier)) break;
-	pointeur_char[j++] = c;
-
-	if ( ++i == 29 )
-	{
-	    pointeur_char = (gchar*)realloc(pointeur_char, j + 1 + 30*sizeof(gchar));
-
-	    if ( !pointeur_char )
-	    {
-		/* 	aie, pb de mmoire, on vire */
-		dialogue_error ( _("Memory allocation error" ));
-		return 0;
-	    }
-	    i = 0;
-	}
-    }
-    pointeur_char[j] = 0;
-
-    *string = pointeur_char;
-
-    if ( feof(fichier))
-	return EOF;
-    else
-	return 1;
-}
-/* ******************************************************************************* */
 
 
 
